/***********/ local filename = "wikidis_ana_PoD_conventional_ivreg" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
include "${PATH_EXTRA_PLUGIN}print_execute.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file runs a conventional iv-approach, where the IV for clicks are clicks on the L0 page (if it was treated)
A more advanced IV-strategy can nuance the instrument combining clicks on the L0 page and link position on the L0 page.
Note that clustering the observations is not possible (same instrument for entire cluster!!
desc_end ***/

local table_stand_alone_path "${PATH_REGRESULT_TABLES}"
cap mkdir `table_stand_alone_path'

*foreach linkdistance in L2 {
local linkdistance L1
local startdata = "${PATH_DISASTER_DATA}wikiPoD_`linkdistance'_pages.dta"	

use "D:\workspace\AAA_wikipedia\wiki_disasters\trunk\wikidis_data\PoD_data\wikiPoD_samples\wikiPoD_L1_post_cleaning.dta", clear
*use "`startdata'", clear
*check startdata


gen flag_real_treat = (1-placebo_state)*flag_treated
gen iv_treat_clicks_L0 = flag_real_treat*clicks_L0
* xtdes
sort mkm_id time_var
gen del_revisions = d.num_revisions
gen del_page_length = d.page_length
gen del_authors = d.num_authors
gen del_refs = d.num_refs
gen del_imagelinks = d.num_imagelinks


local estlabel ivreg_plain

xtreg clicks iv_treat_clicks_L0
eststo `estlabel'0
xtivreg d.num_revisions (clicks = iv_treat_clicks_L0), fe first
eststo `estlabel'1
xtivreg d.num_authors (clicks = iv_treat_clicks_L0), fe 
eststo `estlabel'2
xtivreg del_refs (clicks = iv_treat_clicks_L0), fe 
eststo `estlabel'3
xtivreg del_imagelinks (clicks = iv_treat_clicks_L0), fe 
eststo `estlabel'4
xtivreg del_refs (clicks = iv_treat_clicks_L0), fe 
eststo `estlabel'5

esttab 


local ivtableregs `estlabel'0 `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5
esttab `ivtableregs',  star(* 0.10 ** 0.05 *** 0.01)



local auto_column_titles "Clicks" "Edits" "New Authors" "Length" "Images" "References"
local auto_grouptitles "First Stage" "Second Stage" 
local auto_groups "1 1  0 0 0 0 "
local texoutputfile "  "

		**** objects in table:
		/* check out how many events, pages, observatoins and days are in the dataset  
			and provide that info as local */
			local time  flag_treated		/* add some dummy if it is a crosssection */
			local obs_id page_id		/* specify the adequate variable */
			local cluster_id start_page_name
			
			include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `ivtableregs'"
			local mgroupsoption " `auto_grouptitles', pattern(`auto_groups') prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
			local columntitles " `auto_column_titles' "
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "Simple Instrumental Variable Regression"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "22.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition "NOCH SPEZIELLERE BEMERKUNG "
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table show the results from the Instrumental Variable Regression quantifying the  /*
					*/ effect of attention on content generation. /*
					*/ The instrumental variable is the click-shock to an advertised neighbor when accounting for the position of the link./*
					*/ The first column shows the effect of the instrument on clicks. The other columns (2-6) present the 2nd stage estimates /*
					*/ of how attention affects Edits, new authorsor the addition of text, images or references. The dependent variables are indicated on top. 
					*/ `notetext_addition'/*
					*/ ; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_raw.tex"
			local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

			pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N r2_a ymean, fmt(0 2 2) labels("Observations" "Adj. R$^2$" "Mean of dep. var.")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(5) t(2) nogaps /*  nodepvars compress (nodepvars: no modeltitles, nogaps: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption')  mtitles(`columntitles') /* nomtitles mtitles(`columntitles') 
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			

			
			
**********************
* NOW THE MORE SOPHISTICATED INSTRUMENT
*********************
				
				
				
				
preserve
clear
local path_link_position_data "D:\workspace\AAA_wikipedia\wiki_disasters\trunk\wikidis_data\PoD_data\wikiPoD_samples\"
local link_position_data_full "`path_link_position_data'wikiPoD_L1_with_link_position_in_L0.dta"
use `link_position_data_full'


sort page_id mkm_id 
keep page_id flag_treated placebo_state flag_link_20* sq_link_position_relative link_position_relative link_position_in_L0

local link_position_data "`path_link_position_data'wikiPoD_L1_merge_link_position_in_L0.dta"
save `link_position_data', replace

restore


merge m:1 page_id flag_treated placebo_state using `link_position_data'




gen iv_TreatClicksL0_x_LinkQuint1 = flag_real_treat*clicks_L0*flag_link_20_1
gen iv_TreatClicksL0_x_LinkQuint2 = flag_real_treat*clicks_L0*flag_link_20_2
gen iv_TreatClicksL0_x_LinkQuint3 = flag_real_treat*clicks_L0*flag_link_20_3
gen iv_TreatClicksL0_x_LinkQuint4 = flag_real_treat*clicks_L0*flag_link_20_4
gen iv_TreatClicksL0_x_LinkQuint5 = flag_real_treat*clicks_L0*flag_link_20_5

local controls_i /* e.g. empty */
	* alternative: link_position_in_L0
local controls_j num_revisions num_authors page_length num_imagelinks SNwik_degree 
local controls_k flag_stub flag_long flag_linked flag_super_l1 
local controls_l num_repetitions_link num_L0_links num_links_from_l1 /* e.g. empty */

local reg_controls  num_links_from_l1 is_explanation /* 
	*/  page_length SNwik_degree   num_imagelinks num_refs  
    /* `controls_l' `controls_i' `controls_j' `controls_k' */
sum `reg_controls'


eststo clear
local estlabel "AdvIV" 
xtreg clicks iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1, fe
xtreg clicks iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1 `reg_controls', fe
eststo `estlabel'0
estadd ysumm
xtivreg del_revisions (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1), fe first
xtivreg del_revisions (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1) `reg_controls', fe first
eststo  `estlabel'1
estadd ysumm
xtivreg del_authors (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1), fe 
xtivreg del_authors (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1) `reg_controls', fe 
eststo `estlabel'2
estadd ysumm
*gen del_imagelinks = d.num_imagelinks
*gen del_refs = d.num_refs
xtivreg del_page_length (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1), fe 
xtivreg del_page_length (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1) `reg_controls', fe 
eststo `estlabel'3
estadd ysumm
xtivreg del_imagelinks (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1), fe 
xtivreg del_imagelinks (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1) `reg_controls', fe 
eststo `estlabel'4
estadd ysumm
xtivreg del_refs (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1), fe 
xtivreg del_refs (clicks = iv_TreatClicksL0_x_LinkQuint5 iv_TreatClicksL0_x_LinkQuint4 iv_TreatClicksL0_x_LinkQuint3 iv_TreatClicksL0_x_LinkQuint2 iv_TreatClicksL0_x_LinkQuint1) `reg_controls', fe 
eststo `estlabel'5
estadd ysumm



local ivtableregs `estlabel'0 `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5
esttab `ivtableregs',  star(* 0.10 ** 0.05 *** 0.01)



local auto_column_titles " "Clicks" "Edits" "New Authors" "Length" "Images" "References" "
local auto_grouptitles " "First Stage" "Second Stage"  "
local auto_groups "1 1  0 0 0 0 "
local texoutputfile "  "

		**** objects in table:
		/* check out how many events, pages, observatoins and days are in the dataset  
			and provide that info as local */
			local time  flag_treated		/* add some dummy if it is a crosssection */
			local obs_id page_id		/* specify the adequate variable */
			local cluster_id start_page_name
			
			include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `ivtableregs'"
			local mgroupsoption " `auto_grouptitles' , pattern(`auto_groups') prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
			local columntitles " `auto_column_titles' "
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "Instrumental Variable Regression"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "16.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition "NOCH SPEZIELLERE BEMERKUNG "
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table show the results from the Instrumental Variable Regression quantifying the  /*
					*/ effect of attention on content generation. /*
					*/ The instrumental variable is the click-shock to an advertised neighbor when accounting for the position of the link./*
					*/ The first column shows the effect of the instrument on clicks. The other columns (2-6) present the 2nd stage estimates /*
					*/ of how attention affects Edits, new authors or the addition of text, images or references. The dependent variables are indicated on top. /*
					*/ `notetext_addition'/*
					*/ ; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'.tex"
			local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

			pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N r2_a ymean, fmt(0 2 2) labels("Observations" "Adj. R$^2$" "Mean of dep. var.")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(4) t(2) nogaps /*  nodepvars compress (nodepvars: no modeltitles, nogaps: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `iv_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption')  mtitles(`columntitles') /* nomtitles mtitles(`columntitles') 
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			

log close
xx
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
