	/***********/ local filename = "wikidis_ana_DiffDiff_clustered" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close
set matsize 3000

include "${PATH_PLUGIN}wikidis_plugin_locals.do"
include "${PATH_EXTRA_PLUGIN}print_execute.do"

log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file produces some first regressions (most importantly) of the L2 dataset
desc_end ***/
di "`link_distance_sets'"


local path_output ${PATH_TABLES}
foreach linkdistance in `link_distance_sets' {
* `link_distance_sets' {
* linkdistance in L0 L1 L2

local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_post_cleaning.dta"


local file_includer table_includer
file open `file_includer' using "`path_output'/regtables_`DisPod'_`linkdistance'_includer.tex" , write replace

use "`startdata'", clear

local viewtime 2000

		
*** delta variables, time_dummy_x_treatment, Diff in Diff Variables and time dummies

	local i_need_regressions_vars_yes = "yes"
	local i_need_delta_vars_yes = "yes"
	include "${PATH_PLUGIN}wikidis_plugin_addvars.do"
	* gen under_treatment = flag_treated & (placebo_state == 0)
	
	

		
	forvalues d1 = 1/7 {
		* drop if time_period`d1'
		}
		
	forvalues d2 = 23/29 {
		drop if time_period`d2'
		}
	

local texoutput_file "wiki`DisPod'_explore_slides.tex"
local table_slides_path "${PATH_PAPER_SLIDES}"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"

cap mkdir `table_stand_alone_path'
cap erase "`table_slides_path'/`texoutput_file'"

	di ""
	di ""
	di "*********************************"
	di "* DIFF IN DIFF with clustering"
	di "**********************************"
	di ""
	di ""

	
	
	local estlabel "`DisPod'DiffInDiffXtregClust`linkdistance'"
	
	sort wiki_eve_name flag_treated
	egen clusters_fix_placebo = group(wiki_eve_name flag_treated)
	sum clusters_fix_placebo
	
	sort wiki_eve_name placebo_state
	egen clusters_fix_treatment = group(wiki_eve_name placebo_state)
	sum clusters_fix_treatment
	
	sort wiki_eve_name placebo_state
	egen clusters_all_reg = group(wiki_eve_name placebo_state flag_treated)
	

	pe xtreg clicks  `time_dummies'  `reg_crossterms' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm
	
	pe xtreg clicks  `time_dummies'   `reg_crossterms' if flag_treated == 1, fe robust cluster(clusters_fix_treatment)
	estimates store `estlabel'2
	estadd ysumm

	pe xtreg clicks  `time_dummies'   `reg_crossterms'  , fe robust cluster(clusters_all_reg)
	estimates store `estlabel'5
	estadd ysumm

	pe xtreg del_num_revisions  `time_dummies'  `reg_crossterms' if placebo_state == 0, fe robust cluster(clusters_fix_placebo) 
	estimates store `estlabel'3
	estadd ysumm
	
	pe xtreg del_num_revisions `time_dummies'  `reg_crossterms' if flag_treated == 1, fe robust cluster(clusters_fix_treatment)
	estimates store `estlabel'4
	estadd ysumm

	pe xtreg del_num_revisions  `time_dummies'   `reg_crossterms'  , fe robust cluster(clusters_all_reg)
	estimates store `estlabel'6
	estadd ysumm
	
		* extend as required

	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		local time time_var /* add some dummy if it is a crosssection */
		local obs_id page_id
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do
		
		local example_file example	
		
	local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'5 `estlabel'3 `estlabel'4 `estlabel'6"
	local mgroupsoption "clicks "del revisions", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "compare control" "compare placebo" "compare all" "compare control" "compare placebo" "compare all"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies for `linklabeltext_`linkdistance'' in the  `datatext_`DisPod''."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the results of the reduced form regressions estimating the ITE.   /*
				*/ Columns (1)-(3) show the results for clicks and Columns (4-6) for new edits to the articles. /*
				*/ Specification (1) and (4) contrast treated and comparison group; /*
				*/ (2) and (5) show the comparison of treated articles with themselves but seven weeks earlier (placebo treatment). /*
				*/ In Columns (3) and (6) I juxtapose the treated subnetworks with all available comparison  groups at the same time. /*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms closer to treatment are shown, but all were included. /*
				*/ Reference group t-14 to t-5; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\   /*
				*/ }}}
				
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_`linkdistance'_xtreg_clust.tex"
	local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	pe esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	pe esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') drop(_cons) /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{8}{10} \selectfont \begin{tabular*}" _ "\_" "\end{tabular}" "\end{tabular*}") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
	
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
		
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n

	
	
	di ""
	di ""
	di "*********************************"
	di "* Add before and after "
	di "**********************************"
	di ""
	di ""

	pe xtreg clicks  `reg_crossterms'   if placebo_state == 0 & flag_treated == 1, fe robust cluster(clusters_fix_placebo) 
	estimates store `estlabel'7
	estadd ysumm

	pe xtreg del_num_revisions  `reg_crossterms'  if placebo_state == 0 & flag_treated == 1, fe robust cluster(clusters_fix_placebo) 
	estimates store `estlabel'8
	estadd ysumm


	pe xtreg del_num_authors  `reg_crossterms'  if placebo_state == 0 & flag_treated == 1, fe robust cluster(clusters_fix_placebo) 
	estimates store `estlabel'9
	estadd ysumm

		* extend as required

	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		local time time_var /* add some dummy if it is a crosssection */
		local obs_id page_id
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do
		
		local example_file example	
		
	local regs_to_include " `estlabel'7 `estlabel'1 `estlabel'2 `estlabel'8 `estlabel'3 `estlabel'4 "
	local mgroupsoption "clicks "del revisions", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "before after" "compare control" "compare placebo" "before after" "compare control" "compare placebo"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies for `linklabeltext_`linkdistance'' in the  `datatext_`DisPod''."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the results of the reduced form regressions estimating the ITE .   /*
				*/ Columns (1)-(3) show the results for clicks and Columns (4-6) for new edits to the articles. /*
				*/ Columns (1)-(3) show the results for clicks and Columns (4-6) for new edits to the articles. /*
				*/ (1) and (4) contrast treated and comparison group; Columns (2) and (5) show the comparison of treated articles with themselves /*
				*/ but seven weeks earlier (placebo treatment). Specification (3) and (6) show a simple 'before and after.' /*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms closer to treatment are shown, but all were included. /*
				*/ Reference group t-14 to t-5; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'. /*
				*/ }}}

	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_`linkdistance'_xtreg_clust+bef-after.tex"
	local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	pe esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	pe esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons) /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles')  /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{8}{10} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
	
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
		
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n	
	
	
	
	di ""
	di ""
	di "*********************************"
	di "* ROBUSTNESS "
	di "**********************************"
	di ""
	di ""
	
	/* Diff Diff without the more fishy disasters */
	************************
	if "`DisPod'" == "dis" {	
		pe drop if eve_id == 11
		pe drop if eve_id == 2
		pe drop if eve_id == 5
		pe drop if eve_id == 9	
	}
		
	if "`DisPod'" == "PoD" {	
		pe drop if eve_id < 11
	}

	tab wiki_eve_name flag_real_treatment
		
		local estlabel "`DisPod'DiffDiffRobustXtreg"

		pe  xtreg clicks  `time_dummies'  `reg_crossterms' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estimates store `estlabel'1
		estadd ysumm
		
		pe xtreg clicks  `time_dummies'   `reg_crossterms' if flag_treated == 1, fe robust cluster(clusters_fix_treatment)
		estimates store `estlabel'2
		estadd ysumm
		
		pe xtreg del_num_revisions  `time_dummies'  `reg_crossterms' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estimates store `estlabel'3
		estadd ysumm
		
		pe xtreg del_num_revisions `time_dummies'  `reg_crossterms' if flag_treated == 1, fe robust cluster(clusters_fix_treatment)
		estimates store `estlabel'4
		estadd ysumm

		pe xtreg clicks  `time_dummies'   `reg_crossterms' placebo_state flag_treated, fe robust cluster(clusters_all_reg)
		estimates store `estlabel'5
		estadd ysumm
		

		pe xtreg del_num_authors  `time_dummies'  `reg_crossterms' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estimates store `estlabel'6
		estadd ysumm
		
		pe xtreg del_num_authors `time_dummies'  `reg_crossterms' if flag_treated == 1, fe robust cluster(clusters_fix_treatment)
		estimates store `estlabel'7
		estadd ysumm
		
			* extend as required

		local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'6 `estlabel'7"
		local mgroupsoption "clicks "del revisions" "del authors", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
		local columntitles " "compare control" "compare placebo" "compare control" "compare placebo" "compare control" "compare placebo" "
		local estusingfile "`table_slides_path'/`texoutput_file'"
		local titletext "Robustness Check: Relationship of clicks/added revisions and time dummies for `linklabeltext_`linkdistance'' in the  `datatext_`DisPod'' for only a reduced number of events."
		local scaling "20" /* in percent (0-100) */
		local widthlocal "24.5cm"
		local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
		local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
		local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_`linkdistance'_`estlabel'.tex"
		local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

		/* oder nach tni-style und mit APPEND */
		pe esttab `regs_to_include'/*
			*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
			*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
			*/ mgroups(`mgroupsoption') /*
			*/ mtitles(`columntitles') /* nomtitles */ /*
			*/ title("`titletext' \label{tab:`latexlabel'}")   /*
			*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
			*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
			** export results to .tex file for presentation 
			
		pe esttab `regs_to_include'/*
			*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
			*/ `ymean_stats_display_option' drop(_cons)  /*
			*/ width(`widthlocal') nodepvars compress  /*
			*/ mgroups(`mgroupsoption') /*
			*/ mtitles(`columntitles') /*
			*/ coeflabels(`varname_labels'  `cross_term_labels')/*
			indicate(All dummies = `periods_to_drop')
			*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
			*/ title("`titletext' \label{tab:`latexlabel'}")   /*
			*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
			*/ substitute("\begin{tabular*}" " \fontsize{8}{10} \selectfont \begin{tabular*}" _ "\_" "\begin{table}[h]\centering" "\begin{table}[h]") 
			
			* topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
			** export results to .tex file for presentation */
		
		* file write  `file_includer' "\begin{landscape}" _n
		file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		file write  `file_includer' _n
	
	file close `file_includer'

	
	}
	
	


	
** Rearrange the MainTable

** From clicking L0 to clicking L1

	local regs_to_include " `DisPod'DiffInDiffXtregClustL01 `DisPod'DiffInDiffXtregClustL02 `DisPod'DiffInDiffXtregClustL05 `DisPod'DiffInDiffXtregClustL11 `DisPod'DiffInDiffXtregClustL12 `DisPod'DiffInDiffXtregClustL15"
	local mgroupsoption " "clicks on shocked articles (L0)" "clicks direct vicinity (L1)" "new revisions neighbors (L2)", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "compare control" "compare placebo" "compare all" "compare control" "compare placebo" "compare all"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Transmission of clicks from treated page to neighbors."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "24.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the results of the reduced form regressions estimating the ATE and the ITE in clicks.   /*
				*/ Columns (1)-(3) show the results for the direct effect of treatment on clicks (ATE) /*
				*/ and Columns (4-6) for the spillover to direct neighbors of the articles (ITE). /*
				*/ Specification (1) and (4) contrast treated and comparison group; /*
				*/ (2) and (5) show the comparison of treated articles with themselves but seven weeks earlier (placebo treatment). /*
				*/ In Columns (3) and (6) I juxtapose the treated subnetworks with all available comparison  groups at the same time. /*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms closer to treatment are shown, but all were included. /*
				*/ Reference group t-14 to t-5; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; \\ }}}   
				
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_main_results_L0L1.tex"
	local latexlabel `DisPod'clickL0ToClickL1 /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{12}{14} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */

	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do

		
** From clicking L0 to editing L1

	local regs_to_include " `DisPod'DiffInDiffXtregClustL01 `DisPod'DiffInDiffXtregClustL02 `DisPod'DiffInDiffXtregClustL11 `DisPod'DiffInDiffXtregClustL12 `DisPod'DiffInDiffXtregClustL13 `DisPod'DiffInDiffXtregClustL14 "
	local mgroupsoption " "clicks epicenter (L0)" "clicks direct neighbors (L1)" "new revisions neighbors (L1)", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "compare control" "compare placebo" "compare control" "compare placebo" "compare control" "compare placebo"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "24.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table summarizes the results of the reduced form regressions estimating the spillovers in clicks and edits.   /*
				*/ Columns (1)-(2) show the results for the direct effect of treatment on clicks (ATE) /*
				*/ and Columns (3) and (4) for the spillover to direct neighbors of the articles (ITE). /*
				*/ and Columns (5) and (6) show the conversion of the spillover in clicks to new edits at the direct neighbors. /*
				*/ Specification (1), (3) and (5) contrast treated and comparison group; /*
				*/ (2), (4) and (6) show the comparison of treated articles with themselves but seven weeks earlier (placebo treatment). /*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms closer to treatment are shown, but all were included. /*
				*/ Reference group t-14 to t-5; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; \\    /*
				*/ }}}
	
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_from_clicks_L0_to_edits_L1.tex"
	local latexlabel `DisPod'ClickToEdits /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{12}{14} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */

	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	
** From clicking L0 to editing L1 to authoring L1 - 5 columns

	local regs_to_include " `DisPod'DiffInDiffXtregClustL01 `DisPod'DiffInDiffXtregClustL02 `DisPod'DiffInDiffXtregClustL17 `DisPod'DiffInDiffXtregClustL18 `DisPod'DiffInDiffXtregClustL19 "
	local mgroupsoption " "epicenter (L0)" "direct neighbors (L1)" , pattern(1 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "clicks" "clicks" "clicks" "new edits" "new authors"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table summarizes the results of the reduced form regressions estimating the spillovers in clicks and edits.   /*
				*/ Columns (1)-(2) show the results for the direct effect of treatment on clicks (ATE) /*
				*/ and Columns (3) the spillover to direct neighbors of the articles (ITE). /*
				*/ and Columns (4) show the conversion of the spillover in clicks to new edits at the direct neighbors /*
				*/ and Column (5) shows the number of new author's that contributed to the articles (at the neighbors). /*
				*/ All Specifications are a simple before-after comparison./*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms closer to treatment are shown, but all were included. /*
				*/ Reference group t-14 to t-5; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; \\   /*
				*/ }}}
				
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_from_clicks_L0_to_authors_L1_bef-after.tex"
	local latexlabel `DisPod'ClickToAuthorOverviewXtreg /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{8}{10} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
		
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do

		
if "`link_distance_sets'" == "L0 L1 L2"{

	** From clicking L1 to clicking L2

	local regs_to_include " `DisPod'DiffInDiffXtregClustL11 `DisPod'DiffInDiffXtregClustL12 `DisPod'DiffInDiffXtregClustL15 `DisPod'DiffInDiffXtregClustL21 `DisPod'DiffInDiffXtregClustL22 `DisPod'DiffInDiffXtregClustL25"
	local mgroupsoption " "clicks direct vicinity (L1)" "clicks indirect neighbors (L2)" , pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "compare control" "compare placebo" "compare all" "compare control" "compare placebo" "compare all"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies. Transmission of clicks on treated page to neighbors."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "24.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_main_results_L1L2.tex"
	local latexlabel `DisPod'L1ClicksL2Clicks /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{12}{14} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */


** From clicking L1 to editing L2

	local regs_to_include " `DisPod'DiffInDiffXtregClustL11 `DisPod'DiffInDiffXtregClustL12 `DisPod'DiffInDiffXtregClustL21 `DisPod'DiffInDiffXtregClustL22 `DisPod'DiffInDiffXtregClustL23 `DisPod'DiffInDiffXtregClustL24 "
	local mgroupsoption " "clicks direct vicinity (L1)" "clicks indirect neighbors (L2)" "new revisions neighbors (L2)", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "compare control" "compare placebo" "compare control" "compare placebo" "compare control" "compare placebo"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "24.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_from_clicks_L1_to_edits_L2.tex"
	local latexlabel `DisPod'L1ClicksL2Edits /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{12}{14} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
}

		
log close
exit
