/***********/ local filename = "wikidis_cr_data_test_0_1" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file insheets the new data and filters 
	start_pages and l1_link and produces a simple first start dataset
desc_end ***/

* 1a.) insheet time variant data (the big dataseet)

insheet using "${PATH_RAW_DATA_LOCATION}/wikidis_time_variant_0_1.csv", comma
save "${PATH_INSHEET_DSH}wikidis_l2_pages_time_variant_0_1_raw.dta" , replace
clear all

* 1b.) insheet time invariant data

insheet using "${PATH_RAW_DATA_LOCATION}/wikidis_time_invariant_0_1.csv", comma
save "${PATH_INSHEET_DSH}wikidis_l2_pages_invariant_0_1.dta" , replace
clear all
insheet using "${PATH_RAW_DATA_LOCATION}/wikidis_l1_pages_0_1.txt", tab
gen page_id = l1_page_id
save "${PATH_INSHEET_DSH}wikidis_l1_pages_invariant_0_1.dta", replace
clear all
insheet using "${PATH_RAW_DATA_LOCATION}/wikidis_start_pages_0_1.txt", tab
clonevar page_id = start_page_id
save "${PATH_INSHEET_DSH}wikidis_start_pages_invariant_0_1.dta", replace


/* prepare time_invariant dataset for start pages and L2 data */


use "${PATH_INSHEET_DSH}wikidis_l2_pages_invariant_0_1.dta", clear
merge 1:1 page_id using "${PATH_INSHEET_DSH}wikidis_start_pages_invariant_0_1.dta"
order _merge
browse if _merge != 1
preserve
	tab _merge
	keep if _merge == 3
	rename _merge merger_start_pages
	label var merger_start_pages "1= only in L2 set; 2= only in start_data; 3= in both L2-set and start data"
	save "${PATH_INSHEET_LINK_FLAVOURS}wikidis_start_pages_invariant.dta", replace
restore
tab _merge
keep if _merge == 1
rename _merge merger_start_pages
label var merger_start_pages "1= only in L2 set; 2= only in start_data; 3= in both L2-set and start data"


merge 1:1 (page_id flag_treated) using "${PATH_INSHEET_DSH}wikidis_l1_pages_invariant_0_1.dta"
keep if _merge == 1
rename _merge  merger_L1
label var merger_L1 "1= only in L2 set; 2= only in L1 set; 3= in both L2-set and L1 set"
set seed 47110815
gen sampler = runiform()
save "${PATH_INSHEET_LINK_FLAVOURS}wikidis_pure_L2_pages_invariant.dta", replace

** now merge the time variant and the time invariant data.
	/* N.B.: since the time invaraint data contains only L2 keeping only if _merge == 3 ensures a "pure" L2 dataset */
	

local ptype L2 
foreach ptype in pure_L2 start {

	
	use "${PATH_INSHEET_DSH}wikidis_l2_pages_time_variant_0_1_raw.dta" , clear
	merge m:1 (page_id /*flag_treated*/) using "${PATH_INSHEET_LINK_FLAVOURS}wikidis_`ptype'_pages_invariant.dta"

	tab _merge
	keep if _merge == 3
	rename _merge merger_invariant
	order page_id day eve_id start_page_name eve_time
	save "${PATH_LAST_FULL_L2_DATA}wikidis_pure_`ptype'_pages_full.dta", replace
	gen unix_time_var = day - eve_time
	keep if unix_time_var > - 2*604800
	keep if unix_time_var < 2*604800+86400
	/* generate time_var such that 0 = first observation *AFTER shock */
		gen time_var = .
		replace time_var = int(unix_time_var/86400)-1 if unix_time_var < 0 
		replace time_var = int(unix_time_var/86400) if unix_time_var > 0 
	order page_id time_var unix_time_var eve_id start_page_name  day eve_time
	save "${PATH_LAST_FULL_L2_DATA}wikidis_`ptype'_pages_around_event.dta", replace

	/* rename variables to be in sync with paper 1 */

		* rename v1 day
		* rename v2 page_id
		rename outward_links 					SNwik_out_degree
		rename click_number						clicks
		rename revision_number 					num_revisions  /* is this accurate */
		rename author_number					num_authors
		rename page_lengths 					page_length
		rename rev_stat_image_link_number 		num_imagelinks
		rename rev_stat_is_explanation  		is_explanation 
		rename rev_stat_is_redirect 			is_redirect
		rename rev_stat_literature_number 		has_lit
		rename rev_stat_reference_number 		num_refs
		rename rev_stat_external_links 			num_extlinks
		
		rename indegree_centrality 				SNwik_degree
		* rename global_closeness_in				SNwik_closeness
		* rename global_eigenvector				SNwik_eigenvector
		* rename global_node_number 				SNwik_node_number

		gen zzna_SNwik_between_ggi = .

		/* leave eco_local and soc_local untouched and prepare SNcat - variables 
		gen SNcat_degree	= .
		gen SNcat_between	= .
		gen SNcat_closeness 	= .
		gen SNcat_node_number	= .
		gen SNcat_out_closeness  = .
		*/

		local num_vars = "num_revisions num_imagelinks num_authors num_extlinks num_refs"
		local page_vars = "page_length  is_explanation is_redirect  out_degree "
				

	/* COMPRESS AND MVDECODE */ 
		
		compress
		mvdecode _all, mv(-99)
		compress
		include "${PATH_PLUGIN}wikidis_plugin_labels"
		sort page_id time_var
		by page_id: egen minday = min(day)
		drop if minday < page_first_revision_time

	/* save */
	save "${PATH_DISASTER_DATA}wikidis_`ptype'_pages.dta", replace
	browse

	}
	
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
