/***********/ local filename = "wikidis_anaDesc_figures" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file produces some first sumstats (most importantly) of the L2 dataset
desc_end ***/

foreach linkdistance in `link_distance_sets' {
 * local linkdistance L1 

local startdata = "${PATH_DISASTER_SAMPLES}/wiki`DisPod'_`linkdistance'_post_cleaning.dta"	
use "`startdata'", clear

local viewtime 200
local longview 5000

local i_need_delta_vars_yes = "yes"
include "${PATH_PLUGIN}wikidis_plugin_addvars.do"



**************************
* Defining the variables this file is about
**************************
* xtset mkm_id time_var
* gen del_SNwik_degree = d.SNwik_degree

local time_var 			time_var		/* the_time_variable_if_any */
local core_outcomes		clicks	del_num_authors del_num_revisions del_SNwik_degree /* SNwik_degree clicks	del_num_authors del_num_revision   del_page_length list_of_interesting_dependent_variables */
local core_indep_vars 	""		/* main_rhs_variables */

*** shorten the labels for all variable 
foreach var_to_label in `time_var'   `core_outcomes' `core_indep_vars' {
	local cutlabel  : variable label `var_to_label'
	local shortlabel = substr("`cutlabel'",1 ,41)
	label var `var_to_label' "`shortlabel'"
	des `var_to_label'
	}


******************************
* Graph combines with filewriter
******************************

local path_output = "${PATH_FIGURES}"
local figure_path = "${PATH_FIGURES}" /* note: for tables there are subfolders, but for figures, these are equal */

local path_paper = "${PATH_PAPER_MAIN}"
local figformat = "pdf"


local figure_caller_file "figures_to_include_`linkdistance'_`DisPod'.tex"
local file_includer figure_caller_handle
file open `file_includer' using "`path_output'`figure_caller_file'" , write replace


** figures with outcomes

	** figures with outcomes
	
	local a_values `core_outcomes' 
	
	local crit_b flag_treated
	local b_values 0 1
	local crit_c placebo_state
	local c_values 0 1
	
		
	/* depending where you add one more criterion you get a*b*c graphs rather than 4 graphs (curently) */
	foreach crit_a in `a_values' {
		local idx = 0
		preserve
		*mean variable:
		collapse (mean) /*
			*/ mean_`crit_a'=`crit_a'   /*
			*/ , by (time_var `crit_b' `crit_c') 
			cap label var mean_revisions 		"sum revisions at all neighbors"
			cap label var mean_new_authors 		"all new authors at L1"
			cap label var mean_new_wiklinks 	"all new links at in L1"
			cap label var mean_new_extlinks 	"all new links away from Wikipedia at L1"	
			cap label var mean_page_length 		"total length increase at l1 (bytes)"	
			cap label var mean_content_change	"sum of content edited at L1 (bytes)" 
			cap label var mean_new_refs 		"all new references at neighbors"
			cap label var mean_clicks			"sum of views at neighbors"

		foreach b_value in `b_values' {
			foreach c_value in `c_values' {
				*running index: 
				local idx = `idx' + 1
				
				
				scatter mean_`crit_a' time_var if `crit_b' == `b_value' & `crit_c' == `c_value' /*
						*/ , xline(0) legend(label(1 "`crit_b'=`b_value' + `crit_c'=`c_value'"))
					/* Note: this produces maxidx= a*b*c scatters and saves them as graph_1.gph to graph_maxidx.gph */
				graph save `figure_path'graph_`idx', replace
				

			}
		}
		*** draw the 4 plots in one combined graph corresponting to the crit a - variable
		
		local combi_figure_name "`crit_a'_over_time_`linkdistance'_`DisPod'_2x2"
		local panel_subtitle "" /* Hier kann ein subtitle stehen*/ 
		local truncation_note ""
		local titletext "`crit_a' over time for group: `linkdistance'"
		
		di "`SNA_variables'  `further_SN_vars'  "

		
		graph combine   ///  
			`figure_path'graph_1.gph ///
			`figure_path'graph_2.gph  ///
			`figure_path'graph_3.gph ///
			`figure_path'graph_4.gph ///
					, title(`titletext') ///
					subtitle("`panel_subtitle' `truncation_note'") /*
					*/ rows(3) ysize(16) xsize(16) iscale(0.6)  graphregion(margin(l=0 r=0 t=0 b=0)) ycommon /*ycommon xcommon */

		graph export `figure_path'`combi_figure_name'.`figformat', replace
		* !epstopdf `figure_path'`combi_figure_name'.`figformat'

		
		file write `file_includer' "\begin{figure}" _n
		file write `file_includer' "\begin{center}" _n
		file write `file_includer' "\caption{Figure with means of depvar over time: comparing the groups 2x2}" _n
		file write `file_includer' "\includegraphics[scale=0.3]{`figure_path'/`combi_figure_name'.pdf}" _n
		file write `file_includer' "\end{center}" _n
		file write `file_includer' "\end{figure}" _n
		file write `file_includer' " " _n
		
		sleep `longview'
		restore
	}
	



	* local crit_a clicks
	local a_values `core_outcomes'


	foreach crit_a in `a_values' {
		preserve
		*mean variable:
		collapse (mean) /*
			*/ mean_`crit_a'=`crit_a'   /*
			*/ , by (time_var `crit_b' `crit_c') 

		twoway (line mean_`crit_a' time_var if `crit_c' == 0) || (scatter mean_`crit_a' time_var if `crit_c' == 1)/*
								*/ ,legend(label(1 "`crit_c'=0") label(2 "`crit_c'=1"))
		sleep `viewtime'

		
		twoway (line mean_`crit_a' time_var if `crit_b' == 0) || (scatter mean_`crit_a' time_var if `crit_b' == 1) /*
								*/ ,legend(label(1 "`crit_b'=0")label(2 "`crit_b'=1"))
		sleep `viewtime'

		
	local crit_b flag_treated
	local b_values 0 1
	local crit_c placebo_state
	local c_values 0 1
		
		twoway /*
		*/ (line mean_`crit_a' time_var if `crit_b' == 1 & `crit_c' == 0,  lwidth(thick) ) || /*
		*/ (line mean_`crit_a' time_var if `crit_b' == 1 & `crit_c' == 1,  lpattern(dash))|| /*
		*/ (line mean_`crit_a' time_var if `crit_b' == 0 & `crit_c' == 0    ) ||/*
		 (line mean_`crit_a' time_var if `crit_b' == 0 & `crit_c' == 1,  lpattern(dot)) 
							*/ , xline(0) legend(label(1 "treated in treatment phase") label(2 "treated in placebo-test")/*
							*/ label(3 "not treated, treatment phase") label(4 "not treated, placebo-test") col(2) symxsize(5))

		local combi_figure_name "`crit_a'_over_time_`linkdistance'_`DisPod'_4Lines"
		local panel_subtitle "" /* Hier kann ein subtitle stehen*/ 
		local truncation_note ""
		local titletext "title here"
							
		graph export `figure_path'`combi_figure_name'.`figformat', replace
		* !epstopdf `figure_path'`combi_figure_name'.`figformat'
		
		
		** export dataset for poster
		* save "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`combi_figure_name'_data.dta", replace
		export excel "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`combi_figure_name'_data.xls", firstrow(variables) replace
		
		** write line that calls the figure into a "figurecaller"-file
		file write `file_includer' "\begin{figure}" _n
		file write `file_includer' "\begin{center}" _n
		file write `file_includer' "\caption{Figure with means of depvar over time: looking at all 4 groups in one plot}" _n
		file write `file_includer' "\includegraphics[scale=1]{`figure_path'/`combi_figure_name'.pdf}" _n
		file write `file_includer' "\end{center}" _n
		file write `file_includer' "\end{figure}" _n
		file write `file_includer' " " _n
		
		sleep `longview'
		restore
	}

	file close `file_includer' 
}

clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
