/***********/ local filename = "wikidis_anaDesc_sumstats" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file produces some first sumstats (most importantly) of the L2 dataset
desc_end ***/



local path_output ${PATH_TABLES}
local file_includer table_includer
file open `file_includer' using "`path_output'/wiki`DisPod'_desc_tables_to_include.tex" , write replace
* file write table_includer  "Hello tables" _n 


foreach linkdistance in  `link_distance_sets' {
* foreach linkdistance in  L0 { /*L0 L1 L2 */
local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_post_cleaning.dta"

use "`startdata'", clear

local viewtime 7000
tab time_var,gen(time_period)


local i_need_delta_vars_yes = "yes"
include "${PATH_PLUGIN}wikidis_plugin_addvars.do"





/* beautiful summary-table of all variables with estpost summarize and esttab */

	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		local time time_var /* add some dummy if it is a crosssection */
		local obs_id page_id
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do
		
	local example_file example

	local vars_to_summarize `core_outcomes' `core_indep_vars' `core_SN_vars' `del_vars'
	local if_condition
	local TableNameLabel "FirstSumstatsPanel`linkdistance'`DisPod'"
	local titletext "Summary statistics: `linklabeltext_`linkdistance'' in the  `datatext_`DisPod'' "
	local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab */
	local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{14.8cm}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the distribution of the main variables. /*
				*/ The unit of observations is the outcome of a page i on day t. /*
				*/ The time variable is normalized and runs from -14 to 14.; no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of start pages = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}
	local tableonlyfile "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex"
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using `tableonlyfile', /*
		*/ cells("mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g))  p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ order(`stand_varorder') /*
		*/ coeflabels(`varname_labels') 
	
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n


	
/* beautiful summary-table of main variables with estpost summarize and esttab */

	local vars_to_summarize `core_outcomes' `core_indep_vars' `core_SN_vars' 
	local if_condition
	local TableNameLabel "FirstSumstatsPanelMain`linkdistance'`DisPod'"
	local titletext "Summary statistics: Main variables of `linklabeltext_`linkdistance'' in the  `datatext_`DisPod'': only main variables"
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g))  p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ order(`stand_varorder') /*
		*/ coeflabels(`varname_labels') 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n

	
	
/* beautiful summary-table of differnces (and clicks) with estpost summarize and esttab */

	local vars_to_summarize clicks `del_vars' 
	local if_condition
	local TableNameLabel "FirstSumstatsPaneldel`linkdistance'`DisPod'"
	local titletext "Summary statistics: `TableNameLabel' of variables' first differences"
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g))  p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n
	
	
	
	
/* beautiful summary-table of comparison group differences (and clicks) without treatment 
	...with estpost summarize and esttab */

	local vars_to_summarize clicks `del_vars' 
	local if_condition "if (placebo_state != 0 | flag_treated != 1) "
	local TableNameLabel "SumstPanelDiffNoT`linkdistance'`DisPod'"
	local titletext "Summary statistics: `TableNameLabel' of variables' first differences. Comparison groups"
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g))  p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n

/* beautiful summary-table of comparison group differences (and clicks) before treatment
	...with estpost summarize and esttab */

	local vars_to_summarize clicks `del_vars' 
	local if_condition "if (placebo_state != 0 | flag_treated != 1) & time_var < 0"
	local TableNameLabel "SumstPanelDiffNoTBef`linkdistance'`DisPod'"
	local titletext "Summary statistics: `TableNameLabel' of variables' first differences. Comparison groups"
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g))  p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n

	
/* beautiful summary-table of differences (and clicks) of treated before treatment 
	...with estpost summarize and esttab */


	local vars_to_summarize clicks `del_vars' time_var  
	local if_condition "if placebo_state == 0 & flag_treated == 1 & time_var < 0"
	local TableNameLabel "SumstPanelDiffBefT`linkdistance'`DisPod'"
	local titletext "Summary statistics: `TableNameLabel' of variables' first differences. Treated group."
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g))  p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n
		
	
	
/* beautiful summary-table of differences (and clicks) during treatment 
	...with estpost summarize and esttab */


	local vars_to_summarize clicks `del_vars' time_var 
	local if_condition "if placebo_state == 0 & flag_treated == 1 & time_var > 0"
	local TableNameLabel "SumstPanelDiffInT`linkdistance'`DisPod'"
	local titletext "Summary statistics: `TableNameLabel' of variables' first differences. Treated group."
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g))  p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n
	file write  `file_includer' " \clearpage " _n


/* summary table mit treated und control group shown side by side */

	gen p_grouper = .
	replace p_grouper = 1 if placebo_state == 0 & flag_treated 			/* treated */
	replace p_grouper = 2 if placebo_state == 0 & flag_treated == 0		/* control */
	replace p_grouper = 3 if placebo_state == 1 & flag_treated			/* placebo */	
	replace p_grouper = 4 if placebo_state == 1 & flag_treated == 0		/* controls with placebo */
	* replace p_grouper = 2 if placebo_state == 1 & flag_treated

	preserve
		drop if p_grouper == 4
		drop if time_var >= 0

		local vars_to_summarize `core_outcomes' `core_indep_vars' `core_SN_vars' `del_vars'
		local if_condition "if (p_grouper==1 | p_grouper == 3 | p_grouper == 2) & time_var < 0"

			**** objects in table:
			/* check out how many events, pages, observatoins and days are in the dataset  
				and provide that info as local */
				local time time_var /* add some dummy if it is a crosssection */
				local obs_id page_id
				local cluster_id start_page_name
				
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do



		estpost tabstat `vars_to_summarize' `if_condition'  /*
		  */ , by(p_grouper) statistics(mean sd) columns(statistics) listwise /* nototal */
		est store treat_control

		local if_condition "if p_grouper==2 | p_grouper == 4"
		estpost tabstat `vars_to_summarize' `if_condition'   /* 
		  */ , by(p_grouper) statistics(mean sd) columns(statistics) listwise 
		est store placebo_pseudo



			local titletext "Summary Statistics on Articles by Treatment Status, before Treatment."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
														-- usually via the "substitute()" command in esttab */

			local columntitles " "treated vs. control" "	
			local latexlabel "MainSumstatsByGroups"
			local TableNameLabel "`latexlabel'`linkdistance'`DisPod'"
			local widthlocal "13.5cm"
			local chooselinespace 0.35
			
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{14.8cm}{\scriptsize{{\scshape Notes:} /*
						*/ \scriptsize{The table shows the means of the main variables by treatment status. /*
						*/ The unit of observations is the page i on day t. Column 1 shows treated pages and Column 2 the control group./*
						*/ Column 3 show the treated in the 'placebo' condition, i.e. during a period without treatments. /*
						*/ The time variable is normalized and runs from -14 to 14.; no. of obs. = `num_obs_in_estimation'; /*
						*/ no. of start pages = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}
			local tableonlyfile "${PATH_DESCRIPTIVES_TABLES}`filename'_`TableNameLabel'.tex"


		*esttab treat_control placebo_pseudo  using  `latexlabel'.tex" /*
		esttab treat_control  using  "`tableonlyfile'" /*
			*/ , replace main(mean) aux(sd)  nostar unstack label  /*
			*/  width(`widthlocal') mtitles(`columntitles')  compress /*
			*/  coeflabels(`varname_labels') order()/*
			*/  title("`titletext' \label{tab:`latexlabel'}") /*
			*/  substitute("\begin{tabular*}" " \fontsize{10}{11} \selectfont \begin{tabular*}" _ "\_" "[1em]" "[`chooselinespace'em]" "\end{tabular}" "\end{tabular*}") 

			include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
	restore

/* taboulate the different events (observations: */


	local TableNameLabel "Tabulate_Events_`linkdistance'`DisPod'"
	tab wiki_eve_name
	tabout wiki_eve_name  using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", replace style(tex)
	
 
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n    "\begin{table}[h]"
	file write  `file_includer' _n " \caption{Included events: `linkdistance'`DisPod'}"
    file write  `file_includer' _n "\begin{tabular}{l|c|r} \toprule  "
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
    file write  `file_includer' _n "\bottomrule \end{tabular}"
	file write  `file_includer' _n "\end{table}"
	file write  `file_includer' _n

	local TableNameLabel "Tabulate_Events_by_TreatControl_`linkdistance'`DisPod'"
	gen flag_real_treatment = (placebo_state == 0) & (flag_treated == 1) 
	tabout wiki_eve_name flag_real_treatment using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", replace style(tex)
	drop flag_real_treatment 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n    "\begin{table}[h]"
	file write  `file_includer' _n " \caption{Included events: `linkdistance'`DisPod'}"
    file write  `file_includer' _n "\begin{tabular}{l|c|c|c|r} \toprule  "
	file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
	* file write  `file_includer' "\end{landscape}" _n
    file write  `file_includer' _n "\bottomrule \end{tabular}"
	file write  `file_includer' _n "\end{table}"
	file write  `file_includer' _n
	
/* taboulate the different events: (pages) */
	preserve
	
		keep if time_var == 0 & placebo_state == 0
		
		local TableNameLabel "Tabulate_Events_`linkdistance'`DisPod'_num_pages"
		tab wiki_eve_name
		tabout wiki_eve_name  using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", replace style(tex)

		* file write  `file_includer' "\begin{landscape}" _n
		file write  `file_includer' _n 
		file write  `file_includer' _n "\begin{table}[h]"
		file write  `file_includer' _n " \caption{Included events: `linkdistance'`DisPod'} "
		file write  `file_includer' _n "\begin{tabular}{l|c|r} \toprule  " 		

		file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		file write  `file_includer' _n "\bottomrule \end{tabular}"
		file write  `file_includer' _n "\end{table}"
		file write  `file_includer' _n
		
		local TableNameLabel "Tabulate_Events_by_TreatControl_`linkdistance'`DisPod'_num_pages"
		gen flag_real_treatment = (placebo_state == 0) & (flag_treated == 1) 
		tab wiki_eve_name flag_real_treatment 
		tabout wiki_eve_name flag_real_treatment using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", replace style(tex)
		drop flag_real_treatment 

		* file write  `file_includer' "\begin{landscape}" _n
		file write  `file_includer' _n    "\begin{table}  "
		file write  `file_includer' _n " \caption{Included events: `linkdistance'`DisPod'}"
		file write  `file_includer' _n "\begin{tabular}{l|c|c|c|r} \toprule  "
		file write  `file_includer' _n "\input{${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		file write  `file_includer' _n "\bottomrule \end{tabular}"
		file write  `file_includer' _n  "\end{table}"
		file write  `file_includer' _n
	
	restore

/* alternative sumstats - table with sutex */
	
	/* 	sutex `core_outcomes' `core_SN_vars' `further_SN_vars' time_var, digits(3) minmax file(${PATH_PANEL_TABLES}/sumstats_core_panel.tex)/*
		*/ title(Summary statistics of the panel data.) replace	
		file write sutex_includer "\input{${PATH_PANEL_TABLES}/sumstats_core_panel.tex}" _n
	*/

	
file write `file_includer' " \clearpage " _n
	
}
*******************************************
*** correlations
********************************************
	
** currently only done for the "last dataset" -- which is presumably the relevant one...	
	
	local tex_path ${PATH_DESCRIPTIVES_TABLES}
	
	sort page_id time_var
	local vars_to_correlate `core_outcomes' `core_indep_vars' `core_SN_vars' `del_vars'
	
	* of the levels
	pwcorr `vars_to_correlate'
	* pwcorr `outcomes' `futher_SN_vars'

	*** kill the labels for all variable 
	foreach var_to_label in time_var  `vars_to_correlate' /**/ {
		label var `var_to_label' ""
		}

		
		
	corrtex `core_indep_vars' `core_outcomes' `core_SN_vars' , file(`tex_path'`DisPod'_corrs_levels) sig replace landscape title("Correlations of the levels")
	file write `file_includer' _n "\input{`tex_path'`DisPod'_corrs_levels.tex}" _n _n

	corrtex `core_indep_vars' `del_vars' clicks  , file(`tex_path'`DisPod'_corrs_further_levels) sig replace landscape title("Correlations of the levels")
	file write `file_includer' _n "\input{`tex_path'`DisPod'_corrs_further_levels.tex}" _n _n
	
	/* add sth more intelligent here:
	
	eg. corrtex post_x_treated post_x_real post_x_real_x_treated pre_x_control and a few outcomes
		
		*/

file close `file_includer' 

clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
