	/***********/ local filename = "wikidis_ana_DiffDiff_timeDummies" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close
set matsize 3000


include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file produces some first regressions (most importantly) of the L2 dataset
desc_end ***/


local path_output ${PATH_TABLES}
foreach linkdistance in L1 {
* `link_distance_sets' {
* linkdistance in L0 L1 L2

local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_post_cleaning.dta"


local file_includer table_includer
file open `file_includer' using "`path_output'/regtables_`DisPod'_`linkdistance'_includer.tex" , write replace

use "`startdata'", clear
* keep if sampler < 0.06

local viewtime 7000

*** time dummies
	tab time_var,gen(time_period)
	gen day_counter = .
	egen firstday = min(day)
	local minday = firstday[1]
	local startday = 1
	forvalues daystep = `startday'/1300{
		local sec_intervall_low = `minday' + (`daystep'-1)*86400
		local sec_intervall_high = `minday' + (`daystep')*86400
		di "intervall for day `daystep' = `sec_intervall_low' - `sec_intervall_high'"
		gen day_dummy`daystep' = (day >= `sec_intervall_low') & (day < `sec_intervall_high')
		egen test_the_day_dummy =  total(day_dummy`daystep')
		local test_the_dummy = test_the_day_dummy[_N] 
		di "`test_the_dummy' observations on day `daystep'"
		sum day_dummy`daystep'
		replace day_counter = `daystep' if (day_dummy`daystep' == 1)		
		if `test_the_dummy' == 0 {
			drop day_dummy`daystep'
			}
		* fill a local that exludes time dummies from regression-ouputs:
		if (`daystep' >= 2) & (`test_the_dummy' > 0){
			local hidden_day_dummies `hidden_day_dummies' day_dummy`daystep'
			}
		drop test_the_day_dummy
		}
		
	egen num_days_in_sample = max(day_counter)
	local num_days_in_sample = num_days_in_sample[1]
	drop num_days_in_sample
	drop day_counter
	
	di `num_days_in_sample'
	local day_dummies = "day_dummy`startday'-day_dummy`num_days_in_sample'"
		
*** delta variables
	include "${PATH_PLUGIN}wikidis_plugin_addvars.do"
	* gen under_treatment = flag_treated & (placebo_state == 0)

*** Diff in Diff Variables
	gen post_shock = time_var > 0
	gen shock_x_real = post_shock*(placebo_state == 0)
	gen shock_x_treatment = post_shock*flag_treated
	

*** time_dummy_x_treatment
	gen flag_real_treatment = flag_treated&(placebo==0)
	
	forvalues i = 1/29 {		
		gen realtreat_x_period_`i' = flag_real_treatment*time_period`i'
		}

		
	forvalues d1 = 1/7 {
		drop if time_period`d1'
		}
		
	forvalues d2 = 23/29 {
		drop if time_period`d2'
		}
	
local time_dummies = "time_period9-time_period22"


local reg_crossterms ""
forvalues cr = 11/22{
	local reg_crossterms  `reg_crossterms' realtreat_x_period_`cr'
	}

local texoutput_file "wiki`DisPod'_explore_slides.tex"
local table_slides_path "${PATH_PAPER_SLIDES}"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"
cap mkdir `table_stand_alone_path'



*time_period2 time_period3 time_period4 time_period5 time_period6 time_period7 
local periods_to_drop  time_period9 time_period10  time_period11 time_period12 time_period13 time_period14/*
		*/ time_period22 time_period21 time_period20 time_period19 time_period18 time_period17 time_period16 time_period15
* time_period29 time_period28 time_period27 time_period26 time_period25 time_period24 time_period23 
local crossterms_to_drop realtreat_x_period_11 realtreat_x_period_12 realtreat_x_period_20 realtreat_x_period_21 realtreat_x_period_22
	
	di ""
	di ""
	di "*********************************"
	di "* DIFF IN DIFF with clustering + Robustness"
	di "**********************************"
	di ""
	di ""

	
	
	local estlabel "`DisPod'DIDXtregTDumm"
	
	sort wiki_eve_name flag_treated
	egen clusters_fix_placebo = group(wiki_eve_name flag_treated)
	
	sort wiki_eve_name placebo_state
	egen clusters_fix_treatment = group(wiki_eve_name placebo_state)
	
	sort wiki_eve_name placebo_state
	egen clusters_all_reg = group(wiki_eve_name placebo_state flag_treated)
	

	xtreg clicks  `day_dummies'  `reg_crossterms' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm
	
	xtreg clicks  `day_dummies'   `reg_crossterms' if flag_treated == 1, fe robust cluster(clusters_fix_treatment)
	estimates store `estlabel'2
	estadd ysumm

	xtreg clicks  `day_dummies'   `reg_crossterms', fe robust cluster(clusters_all_reg)
	estimates store `estlabel'5
	estadd ysumm

	xtreg del_num_revisions  `day_dummies'  `reg_crossterms' if placebo_state == 0, fe robust cluster(clusters_fix_placebo) 
	estimates store `estlabel'3
	estadd ysumm
	
	xtreg del_num_revisions `day_dummies'  `reg_crossterms' if flag_treated == 1, fe robust cluster(clusters_fix_treatment)
	estimates store `estlabel'4
	estadd ysumm

	
		* extend as required

	local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 "
	local mgroupsoption "clicks "del revisions", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "compare control" "compare placebo" "compare control" "compare placebo" "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies."
	local scaling "50" /* in percent (0-100) */
	local widthlocal "16cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-7 to t-5"
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_`linkdistance'_xtreg_timeDummies.tex"
	local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_term_labels')/*
		*/ drop(o.* day_dummy*) /*

		indicate(All dummies = `periods_to_drop')
		*/ indicate("All cross = `crossterms_to_drop'" ) /* "Time Dummies = `hidden_day_dummies'" "Time Dummies = `periods_to_drop'")
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n



}


log close
exit
