/***********/ local filename = "wikidis_ana_L2test_analysis" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file performs a first showcase analysis of the disaster data
desc_end ***/




local startdata =  "${PATH_DISASTER_DATA}wikidis_pure_L2_pages.dta"	

use "`startdata'", clear

**check startdata
replace wiki_eve_name = "Sichuan_Earthquake_2008" if wiki_eve_name == "Erdbeben_in_Sichuan_2008"
tab  start_page_name wiki_eve_name 
xtset page_id time_var

/* descriptives as tables */


	* generate depvar and treatment indicators
		include wikidis_plugin/wikidis_plugin_addvars
		* drop flag*
		include wikidis_plugin/wikidis_plugin_flags
	
		gen flag_post_shock = time_var >= 0
		gen flag_treatm_active = flag_treated * flag_post_shock
		
		tab time_var, gen(time_)
		
		forvalues i = 1/14 {
			local time = `i' 
			gen treated_in_`time' = flag_treated*time_`i'
		}
 
 		forvalues i = 15/29 {
			local time = `i' - 15 
			gen treated_since_`time' = flag_treated*time_`i'
		}
 
		local time_dummies "time_1 - time_14 time_16-time_29"
		local treatment_dummies "treated_in_1 - treated_in_14 treated_since_1 - treated_since_14 "
		
		foreach vari in page_length num_authors num_revisions num_refs num_extlinks {
			gen del_`vari' = d.`vari'
			}
		
	local vars_to_summarize clicks del_page_length del_num_authors del_num_revisions del_num_refs del_num_extlinks 
	local outcomes_to_hide 
			* num_imagelinks num_refs num_extlinks clicks num_revisions page_lang_links 

	sum `vars_to_summarize '
	
	*** table treated observations
	local if_condition "if eve_id == 8 & flag_treated & flag_treatm_active"
	count `if_condition'
	local numobs_in_sumstats = r(N)
	
	local TableNameLabel "L2TestChOfActvtyTreatPost"
	local titletext "Summary statistics of activity. Treated articles while in treatment."
	local addnotes_line1 "Number of observations: `numobs_in_sumstats'"

	local default_alignment "|crrrrrrr"
	local prehead_options  %by\_prehead  "\begin{table}[htbp]\centering" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\caption{`titletext' \label{tab:`TableNameLabel'}}" "\linespread{1.5} \fontsize{12}{12}" "\selectfont"  "\begin{tabular}{l*{1}{`default_alignment'}}" "\toprule"
	local default_sumcells "count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))"
	estpost summarize `vars_to_summarize' `if_condition' , detail   	
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}/`TableNameLabel'.tex", /*
		*/ cells("`default_sumcells'")   /* alignment("default_alignment")
		/* sd(fmt(%11.2g))  */
		*/ prehead(`prehead_options') posthead()  /*
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ drop(`outcomes_to_hide' ) nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') addnote("`addnotes_line1'") /*
		*/ order() 
	
	/* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' "\normalsize{" _n
	file write  `file_includer' "\input{${PATH_DESCRIPTIVES_TABLES}/`TableNameLabel'.tex}" _n
	file write  `file_includer' "}" _n
	* file write  `file_includer' "\end{landscape}" _n
	*/
	
	
	*** treated observations before treatment
	local if_condition "if eve_id == 8 & flag_treated & flag_treatm_active==0 "
	count `if_condition'
	local numobs_in_sumstats = r(N)
	
	local TableNameLabel "L2TestChOfActvtyTreatAnte"
	local titletext "Summary statistics of activity. Treated articles before treatment."
	local addnotes_line1 "Number of observations: `numobs_in_sumstats'"

	
	local prehead_options  %by\_prehead  "\begin{table}[htbp]\centering" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\caption{`titletext' \label{tab:`TableNameLabel'}}" "\linespread{1.5} \fontsize{12}{12}" "\selectfont"  "\begin{tabular}{l*{1}{`default_alignment'}}" "\toprule"

	estpost summarize `vars_to_summarize' `if_condition' , detail   	
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}/`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		/* sd(fmt(%11.2g)) */
		*/ prehead(`prehead_options') posthead()  /* alignment(crrrrrrr)
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ drop(`outcomes_to_hide' ) nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') addnote("`addnotes_line1'") /*
		*/ order() 

	*** untreated observations
	local if_condition "if eve_id == 8 & flag_treated==0 & flag_post "
	count `if_condition'
	local numobs_in_sumstats = r(N)
	
	local TableNameLabel "L2TestChOfActvtyContPost"
	local titletext "Summary statistics of activity. Control group articles during treatment phase."
	local addnotes_line1 "Number of observations: `numobs_in_sumstats'"

	
	local prehead_options  %by\_prehead  "\begin{table}[htbp]\centering" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\caption{`titletext' \label{tab:`TableNameLabel'}}" "\linespread{1.5} \fontsize{12}{12}" "\selectfont"  "\begin{tabular}{l*{1}{`default_alignment'}}" "\toprule"

	estpost summarize `vars_to_summarize' `if_condition' , detail   	
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}/`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		/* sd(fmt(%11.2g)) */
		*/ prehead(`prehead_options') posthead()  /* alignment(crrrrrrr)
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ drop(`outcomes_to_hide' ) nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') addnote("`addnotes_line1'") /*
		*/ order() 
		
		*** control group observations before treatment
	local if_condition "if eve_id == 8 & flag_treated==0 & flag_post==0 "
	count `if_condition'
	local numobs_in_sumstats = r(N)
	
	local TableNameLabel "L2TestChOfActvtyContAnte"
	local titletext "Summary statistics of activity. Control group articles before treatment."
	local addnotes_line1 "Number of observations: `numobs_in_sumstats'"

	
	local prehead_options  %by\_prehead  "\begin{table}[htbp]\centering" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" "\caption{`titletext' \label{tab:`TableNameLabel'}}" "\linespread{1.5} \fontsize{12}{12}" "\selectfont"  "\begin{tabular}{l*{1}{`default_alignment'}}" "\toprule"

	estpost summarize `vars_to_summarize' `if_condition' , detail   	
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}/`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		/* sd(fmt(%11.2g)) */
		*/ prehead(`prehead_options') posthead()  /* alignment(crrrrrrr)
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ drop(`outcomes_to_hide' ) nolabel booktabs replace /*
		*/ coeflabels(`varname_labels') addnote("`addnotes_line1'") /*
		*/ order() 	
		
/* a few descriptive figures */


* local draw_level_graphs_yes = "yes"
local figure_path = "${PATH_FIGURES}" 
local tex_path =  "${PATH_DESCRIPTIVES_TABLES}"
local figformat "eps"

cap mkdir `figure_path'
cap mkdir `tex_path'

	*** tamper with label of time_var
	foreach vari in time_var start_page_name {
		local cutlabel  : variable label `vari'
		local shortlabel = substr("`cutlabel'",1 ,20)
		label var `vari' "`shortlabel'"
		}

		
/*	*** draw a few figures
	sort time_var eve_id flag_treated 
	foreach out_var in page_length  SNwik_degree num_imagelinks num_extlinks num_refs clicks num_revisions num_authors  {
		by time_var eve_id flag_treated: egen avg_grp_`out_var' = mean(`out_var')
		twoway line  avg_grp_`out_var' time_var, by(start_page_name ) /*
			*/ saving(`figure_path'/wikidis_2disasters_`out_var'.gph, replace) /*
			*/ legend(cols(1) rowgap(tiny) colgap(minuscule) symxsize(*0.4)  keygap(minuscule) /*
			*/ size(small) region(margin(tiny) lwidth(medthin)) bmargin(tiny)) /*
			*/ ylabel(#4, alternate)
		
		local figure_name = "wikidis_`out_var'_vs_time"
			* graph export xy.png, replace	
		graph export `figure_path'/`figure_name'.`figformat', replace
		!epstopdf `figure_path'/`figure_name'.`figformat'
		rm `figure_path'/`figure_name'.`figformat'
		*sleep 2000
		}
 

	local out_var sum_clicks_pointing
	by time_var eve_id flag_treated: egen avg_grp_sum_clicks_pointing = mean(sum_clicks_on_pages_pointing_to)
	twoway line  avg_grp_sum_clicks_pointing time_var, by(start_page_name ) /*
			*/ saving(`figure_path'/wikidis_2disasters_`out_var'.gph, replace) /*
			*/ legend(cols(1) rowgap(tiny) colgap(minuscule) symxsize(*0.4)  keygap(minuscule) /*
			*/ size(small) region(margin(tiny) lwidth(medthin)) bmargin(tiny)) /*
			*/ ylabel(#4, alternate)
		
	* sleep 4000
	
	local figure_name = "wikidis_`out_var'_vs_time"
		graph export `figure_path'/`figure_name'.`figformat', replace
		!epstopdf `figure_path'/`figure_name'.`figformat'
	/*
		file write `file_includer' "\begin{figure}" _n
		file write `file_includer' "\caption{Figure with means over time: The Figure shows the development of the p50 of the Network Variables in the connected and the smaller jumping sample over time.}" _n
		file write `file_includer' "\includegraphics[scale=0.4]{`figure_path'/`combi_figure_name'.pdf}" _n
		file write `file_includer' "\end{figure}" _n
		file write `file_includer' " " _n
	*/
	

*/
tab eve_id wiki_eve_name





********
** first diff in diff regressions
********

sort page_id time_var
xtset page_id time_var

* prepare files for output
local texoutput_file "wikidis_explore_disasters.tex"
local table_slides_path "${PATH_OUTPUT_SLIDES}"
local table_stand_alone_path "${PATH_DESCRIPTIVES_TABLES}"
cap mkdir `table_stand_alone_path'

*** Two Disasters Pure
local estlabel "TwoDisastPure"


* regressions, by disaster
regress del_page_length  flag_post_shock `treatment_dummies' `time_dummies' if eve_id == 5,  robust /* flag_treated */
estimates store lehman
regress del_page_length  flag_post_shock `treatment_dummies' `time_dummies' if eve_id == 8,  robust /* flag_treated */
estimates store sichuan 

* final specification
xi: regress del_page_length  flag_post_shock  `treatment_dummies' `time_dummies' i.eve_id , robust /* flag_treated */
estimates store both

xi: xtreg del_page_length  flag_post_shock  `treatment_dummies' `time_dummies', fe robust 
estimates store fe 


*** prepare esttab
	local regs_to_include   "both sichuan lehman "
	local columntitles " "Both Events" "Sichuan only" "Lehman only"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Diff in Diff: Generation of content (page length) during treatment and for the control group."
	local scaling "60" /* in percent (0-100) */
	local widthlocal "15.5cm"
	local addnotetext1 "Pooled OLS-Regressions with robust standard errors. "
	local addnotetext2 "Dependent Variable: page_length (first difference)."
	local tableonlyfile "`table_stand_alone_path'`estlabel'.tex"

	
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') nodepvars compress  /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`label'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  b(3) t(2) /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N N_g r2_a, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') nodepvars compress  /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`label'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  b(3) t(2) /*
		topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
		

*** Two Disasters Control		
local estlabel "TwoDisastCont"

local controls page_length num_authors has_lit num_revisions SNwik_degree

* regressions, by disaster
regress del_page_length  flag_post_shock `treatment_dummies' `time_dummies' `controls' if eve_id == 5,  robust /* flag_treated */
estimates store `estlabel'1


regress del_page_length  flag_post_shock `treatment_dummies' `time_dummies' `controls' if eve_id == 8,  robust /* flag_treated */
estimates store `estlabel'2

* final specification
xi: regress del_page_length  flag_post_shock `treatment_dummies' `time_dummies' i.eve_id `controls', robust /* flag_treated */
estimates store `estlabel'3

xi: xtreg del_page_length  flag_post_shock `treatment_dummies' `time_dummies'   `controls', fe robust /* flag_treated */
estimates store `estlabel'4

*** prepare esttab
	local regs_to_include   " `estlabel'3  `estlabel'2  `estlabel'1  "
	local columntitles " "Both Events" "Sichuan only" "Lehman only"   "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Diff in Diff: Generation of content (page length) during treatment and for the control group."
	local scaling "50" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Pooled OLS-Regressions with robust standard errors. Dependent Variable: page_length (1st diff). "
	local addnotetext2 ""
	local tableonlyfile "`table_stand_alone_path'`estlabel'.tex"

	
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') nodepvars compress  /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`label'}")   /*
		*/ addnote("`addnotetext1'")	  b(3) t(2) /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N N_g r2_a, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') nodepvars compress  /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`label'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  b(3) t(2) /*
		topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
		
		
********
** looking at the click mechanism
*******
/*
sort page_id time_var
xtreg d.clicks d.sum_clicks_on_pages_pointing_to, fe
xtreg d.clicks d.sum_clicks_on_pages_pointing_to if flag_treated, fe
xtreg d.clicks d.sum_clicks_on_pages_pointing_to if flag_treatm_active, fe


xtreg clicks sum_clicks_on_pages_pointing_to, fe
xtreg clicks sum_clicks_on_pages_pointing_to if flag_treated, fe
xtreg clicks sum_clicks_on_pages_pointing_to if flag_treatm_active, fe

 */
 
* xx

clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
