/***********/ local filename = "wikidis_ana_long_term_effects_weekly" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close


include "${PATH_EXTRA_PLUGIN}print_execute.do" 
include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file runs diff diff pe regress ions for the long run effects of being the neighbor of an advertised page.
(first diff pre-computed, now in the cross-section) 
desc_end ***/


local texoutput_file "wiki`DisPod'_explore_slides.tex"
local table_slides_path "${PATH_PAPER_SLIDES}"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"

cap mkdir `table_stand_alone_path'

cap include "${PATH_EXTRA_PLUGIN}print_execute.do"

local data0 "${PATH_DISASTER_SAMPLES}wiki`DisPod'_L0_peaks.dta"
local data1 "${PATH_DISASTER_SAMPLES}wiki`DisPod'_L1_by_event.dta"
* local data1 "${PATH_DISASTER_SAMPLES}wiki`DisPod'_L1_peaks.dta"


foreach distance in 0 1 {
* local distance 1
di "run `distance'"
local linkdistance L`distance'
local startdata "`data`distance''"

pe use "`startdata'", clear

local estlabel "LongTerm`linkdistance'" /* if in loop: pick sth that depands on iterable */

pe sort start_page_name
pe egen temp_id = group(start_page_name)
bys temp_id: gen temp_counter = _N
drop if temp_counter > 2
xtset temp_id placebo_state
drop temp_counter 



/* estimates */
foreach var in num_authors num_revisions page_length num_refs num_imagelinks num_extlinks  {
	cap rename week_diff_after_`var' raw_diff_after_`var'
	* gen week_diff_after_`var' = del_15_22_`var' - del_8_15_`var'
	* gen week_diff_after_`var' = del_15_22_`var' - del_1_8_`var'
	* gen week_diff_after_`var' = log(del_15_22_`var'+1) - log(del_1_8_`var'+1)
	* gen week_diff_after_`var' = del_15_20_`var' - del_1_6_`var'
	* gen week_diff_after_`var' = log(del_15_18_`var'+1) - log(del_1_4_`var'+1)
	* gen week_diff_after_`var' = del_15_22_`var'
	* gen week_diff_after_`var' = del_1_8_`var'
	* gen week_diff_after_`var' = log(del_15_22_`var'+1)
	/* difference between real treatment and Placebo condition: */
		cap drop hlp_diff_after_`var' 
		* pe gen hlp_diff_after_`var' = D.del_15_22_`var'
		pe gen hlp_diff_after_`var' = D.del_15_22_`var'
		by temp_id: egen hlp2_diff_after_`var' = max(hlp_diff_after_`var')
		gen week_diff_after_`var'  = - hlp2_diff_after_`var' 
		* gen week_diff_after_`var'  = log(hlp2_diff_after_`var'+1) 
		
	}

	
/* drop outliers  */
*****************
local outlier_vars week_diff_after_page_length
foreach var in `outlier_vars' {
	local rigorlevel 3 /* select 1 2 or 3 */
	centile `var' if flag_treated & placebo_state == 0, centile(98 99 99.5)
	local threshhold int(r(c_`rigorlevel'))
	di "`threshhold'"
	pe drop if `var' > `threshhold'
	centile `var' if flag_treated & placebo_state == 0, centile(2 1 0.05)
	local threshhold int(r(c_`rigorlevel'))
	di "`threshhold'"
	pe drop if `var' < `threshhold'
	
	}
	
* pe xtreg pe regress  `depvar' `var_of_interest', fe etc. 



local num_variables  refs imagelinks extlinks  
local depvar_list authors length `num_variables'
local controls  num_extlinks num_refs has_lit num_imagelinks page_length num_authors clicks peak_clicks

local vars_to_summarize week_diff_after_page_length week_diff_after_num_revisions  week_diff_after_num_authors week_diff_after_num_refs  /*
						*/ week_diff_after_num_imagelinks week_diff_after_num_extlinks `controls' 
local if_condition "if flag_treated == 1"
local TableNameLabel "SumstWeeklyDiffTreat`linkdistance'"
local titletext "Summary statistics: `TableNameLabel' of WeekDiff variables"

	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ order(`stand_varorder') /*
		*/ coeflabels(`varname_labels') /*
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
				*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
				*/ _ "\_" )
		

local if_condition "if flag_treated == 0"
local TableNameLabel "SumstWeeklyDiffNoTreat`linkdistance'"
local titletext "Summary statistics: `TableNameLabel' of WeekDiff variables"

	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "${PATH_DESCRIPTIVES_TABLES}`TableNameLabel'.tex", /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs  title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ nolabel booktabs replace /*
		*/ order(`stand_varorder') /*
		*/ coeflabels(`varname_labels') /*
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
				*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
				*/ _ "\_" )
		
		
pe regress  week_diff_after_num_authors flag_treated if placebo_state == 0, robust
estimates store `estlabel'0
estadd ysumm


pe regress  week_diff_after_page_length flag_treated if placebo_state == 0, robust
estimates store `estlabel'1
estadd ysumm

pe regress  week_diff_after_num_refs flag_treated if placebo_state == 0, robust
estimates store `estlabel'2
estadd ysumm

pe regress  week_diff_after_num_imagelinks  flag_treated if placebo_state == 0, robust
estimates store `estlabel'3
estadd ysumm

pe regress  week_diff_after_num_extlinks  flag_treated if placebo_state == 0, robust
estimates store `estlabel'4
estadd ysumm



pe regress  week_diff_after_num_authors placebo_state if flag_treated == 1, robust
estimates store `estlabel'5
estadd ysumm

pe regress  week_diff_after_page_length placebo_state if flag_treated == 1, robust
estimates store `estlabel'6
estadd ysumm

pe regress  week_diff_after_num_refs placebo_state if flag_treated == 1, robust
estimates store `estlabel'7
estadd ysumm

pe regress  week_diff_after_num_imagelinks placebo_state if flag_treated == 1, robust
estimates store `estlabel'8
estadd ysumm


pe regress   week_diff_after_num_extlinks  placebo_state if flag_treated == 1, robust
estimates store `estlabel'9
estadd ysumm


	pe sort page_id placebo_state flag_treated
	egen crosssect_id = group(page_id placebo_state flag_treated)

	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		* cap gen time_var=0
		local time time_var 		/* add some dummy if it is a crosssection */
		local obs_id 	crosssect_id	/* specify the adequate variable */
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

 
* extend as required

	local regs_to_include " `estlabel'0 `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5 `estlabel'6 `estlabel'7 `estlabel'8 `estlabel'9"
	local mgroupsoption " "Comparison Group 1" "Comparison Group 2", pattern(1 0 0 0 0 1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles `depvar_list' `depvar_list'
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Longterm-effects on Content Generation in `linkdistance' - Dependent variables: `depvarlist'"
	local scaling "50" /* in percent (0-100) */
	local widthlocal "24.5cm"  /* hochformat 16.5cm; querforma t 24.5cm */
	local addnotetext1 "OLS-pe regress ions with robust standard errors."
	local addnotetext2 "Only x y z. Dependent Variable: `outcome`x''."
	local signs_to_erase_in_notes 29 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows ... /*
				*/ OLS regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observation is the outcome page i. Standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

	local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'.tex"
	local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/
	
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
		*/ nodepvars compress  se(3)  b(3) t(2) /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N N_g r2_a ymean, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$" "mean(dep. var.)")) /* 
			in plugin_locals definieren
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
			in plugin_locals definieren
		*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
			in plugin_locals definieren
		*/ coeflabels(`nice_labels')/* 
			in plugin_locals definieren
		*/ nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
			*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
			*/ _ "\_" "\end{tabular}" "\end{tabular*}")  


	/* call file that includes tablenotes */
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	
	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n
	*/
	
***********************
* with controls
***********************

local estlabel "LongTermControl`linkdistance'" /* if in loop: pick sth that depands on iterable */

	pe regress  week_diff_after_num_authors  flag_treated  `controls' if placebo_state == 0, robust
	estimates store `estlabel'0
	estadd ysumm


	pe regress  week_diff_after_page_length flag_treated  `controls' if placebo_state == 0, robust
	estimates store `estlabel'1
	estadd ysumm

	pe regress  week_diff_after_num_refs flag_treated  `controls' if placebo_state == 0, robust
	estimates store `estlabel'2
	estadd ysumm

	pe regress  week_diff_after_num_imagelinks  flag_treated  `controls' if placebo_state == 0, robust
	estimates store `estlabel'3
	estadd ysumm

	pe regress  week_diff_after_num_extlinks  flag_treated  `controls'  if placebo_state == 0, robust
	estimates store `estlabel'4
	estadd ysumm



	pe regress  week_diff_after_num_authors placebo_state  `controls' if flag_treated == 1, robust
	estimates store `estlabel'5
	estadd ysumm

	pe regress  week_diff_after_page_length placebo_state  `controls' if flag_treated == 1, robust
	estimates store `estlabel'6
	estadd ysumm

	pe regress  week_diff_after_num_refs placebo_state  `controls'  if flag_treated == 1, robust
	estimates store `estlabel'7
	estadd ysumm

	pe regress  week_diff_after_num_imagelinks placebo_state  `controls' if flag_treated == 1, robust
	estimates store `estlabel'8
	estadd ysumm


	pe regress   week_diff_after_num_extlinks  placebo_state  `controls' if flag_treated == 1, robust
	estimates store `estlabel'9
	estadd ysumm


	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		* cap gen time_var=0
		local time time_var 		/* add some dummy if it is a crosssection */
		local obs_id 	crosssect_id	/* specify the adequate variable */
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

 
* extend as required

	local regs_to_include " `estlabel'0 `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5 `estlabel'6 `estlabel'7 `estlabel'8 `estlabel'9"
	local mgroupsoption " "Comparison Group 1" "Comparison Group 2", pattern(1 0 0 0 0 1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles `depvar_list' `depvar_list'
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Longterm-effects on Content Generation in `linkdistance' - Dependent variables: `depvarlist'"
	local scaling "50" /* in percent (0-100) */
	local widthlocal "24.5cm"  /* hochformat 16.5cm; querforma t 24.5cm */
	local addnotetext1 "OLS-pe regress ions with robust standard errors."
	local addnotetext2 "Only x y z. Dependent Variable: `outcome`x''."
	local signs_to_erase_in_notes 29 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows ... /*
				*/ OLS regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observation is the outcome page i. Standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

	local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'.tex"
	local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/
	
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
		*/ nodepvars compress  se(3)  b(3) t(2) /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N N_g r2_a ymean, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$" "mean(dep. var.)")) /* 
			in plugin_locals definieren
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
			in plugin_locals definieren
		*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
			in plugin_locals definieren
		*/ coeflabels(`varname_labels')/* 
			in plugin_locals definieren
		*/ nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
			*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
			*/ _ "\_" "\end{tabular}" "\end{tabular*}")  


	/* call file that includes tablenotes */
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	
	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf 
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n
	*/	
	
	}
	

	
*************************
* Nice table that collects the results.
*************************

	* extend as required

	local regs_to_include " LongTermL00 LongTermL01 LongTermL02 LongTermL03 LongTermL04 LongTermL10 LongTermL11 LongTermL12 LongTermL13 LongTermL14"
	local mgroupsoption " "changes on featured page" "changes on all neighbors", pattern(1 0 0 0 0 1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles `depvar_list' `depvar_list'
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Longterm-effects on Content Generation on the treated page vs. all neighbors."
	local scaling "50" /* in percent (0-100) */
	local widthlocal "24.5cm"  /* hochformat 16.5cm; querforma t 24.5cm */
	local addnotetext1 "OLS-pe regress ions with robust standard errors."
	local addnotetext2 "Only x y z. Dependent Variable: `outcome`x''."
	local signs_to_erase_in_notes 29 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows compares the content that was generated and persisted for a week. /*
				*/ The first five columns show the changes that were mode on the treated page. /*
				*/ Columns (6)-(10) show the after week changes aggregated over all neighbors. /*
				*/ In both groups, the dependent variables are: (1) new authors, (2) change in length, (3) change in references,  /*
				*/ (4) change in images and (5) change in extrenal links. All changes in content are measured in absolute terms. /*
				*/ Diff in Diff regressions: The first difference is between the third week under real vs. the third week under placebo, /*
				*/ The second difference is between treated (clusters of) articles and untreated ones. /*
				*/ Heteroscedasticity robust standard errors. /*
				*/ The unit of observation is the outcome page (or cluster) i. Standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

	local tableonlyfile "`table_stand_alone_path'`filename'_LongtermL0vsL1.tex"
	local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/
	
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
		*/ nodepvars compress  nonotes se(3)  b(3) t(2) /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N /* r2_a "Adj. R$^2$"  ymean "mean(dep. var.)"*/ , fmt(0 /*0 3*/) labels("Number of Page Clusters" )) /* 
			in plugin_locals definieren
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
			in plugin_locals definieren
		*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
			in plugin_locals definieren
		*/ coeflabels(`varname_labels')/* 
			in plugin_locals definieren
		*/ nodepvars compress nonotes /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
			*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
			*/ _ "\_" "\end{tabular}" "\end{tabular*}")  


	/* call file that includes tablenotes */
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	
	

*************************
* Further Checks just in the Log-file
*************************
	
local linkdistance L1
local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_by_event.dta"	

use "`startdata'", clear

pe regress  week_diff_after_page_length flag_treated if placebo_state == 0
pe regress  week_diff_after_num_refs flag_treated if placebo_state == 0
pe regress  week_diff_after_num_refs flag_treated if placebo_state == 0
pe regress  week_diff_after_num_imagelinks  flag_treated if placebo_state == 0
pe regress  week_diff_after_num_extlinks  flag_treated if placebo_state == 0
pe regress  week_diff_after_num_authors  flag_treated if placebo_state == 0


pe regress  week_diff_after_page_length placebo_state if flag_treated == 1
pe regress  week_diff_after_num_refs placebo_state if flag_treated == 1
pe regress  week_diff_after_num_authors placebo_state if flag_treated == 1
pe regress  week_diff_after_num_imagelinks placebo_state if flag_treated == 1
pe regress  week_diff_after_num_extlinks placebo_state if flag_treated == 1
pe regress  week_diff_after_num_refs placebo_state if flag_treated == 1

pe regress  week_diff_after_page_length placebo_state if flag_treated == 0
pe regress  week_diff_after_num_refs placebo_state if flag_treated == 0





clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
