/***********/ local filename = "wikidis_ana_peak_heterogenity_spills" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close

include "${PATH_EXTRA_PLUGIN}print_execute.do"

include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file analyzes whether the initial peak on an L0-page systematically affects the 
	average clicks on the neighbours.
	the peak on the L1-pages is pe regressed on the peak on their L0 page...
desc_end ***/



*foreach linkdistance in L2 {
local linkdistance L1
local startdata "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_with_L0_peaks.dta"

if "${LINK_POSITION_DATA_PASSED_YES}"  == "yes" {
	local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_with_L0_peaks_without_umlaut.dta"
	}
use "`startdata'", clear


gen eligible_and_treated = (flag_treated) * (placebo_state==0)


foreach flag in flag_stub flag_long flag_linked flag_super_l1 {
	gen `flag'_x_L0_peak_clicks = `flag' * L0_peak_clicks
	local crosslist `crosslist' `flag'_x_L0_peak_clicks
	}



sum L0_peak_clicks
bys flag_treated: sum L0_peak_clicks
bys placebo_state: sum L0_peak_clicks
bys placebo_state flag_treated: sum L0_peak_clicks


bys placebo_state flag_treated: tab L0_peak_clicks
tab start_page_name if L0_peak_clicks == 0
bys placebo_state flag_treated: tab start_page_name if L0_peak_clicks == 0

* 1.) Overall Correlations
***************************
corr L0_peak_clicks peak_clicks agg_clicks_after agg_clicks_before avg_clicks/*
	*/ L0_agg_clicks_after L0_agg_clicks_before L0_avg_clicks 

* 2.) By treatment groups
***************************
corr L0_peak_clicks peak_clicks agg_clicks_after agg_clicks_before avg_clicks/*
	*/ L0_agg_clicks_after L0_agg_clicks_before L0_avg_clicks if placebo_state==0 & flag_treated 

corr L0_peak_clicks peak_clicks agg_clicks_after agg_clicks_before avg_clicks/*
	*/ L0_agg_clicks_after L0_agg_clicks_before L0_avg_clicks if placebo_state==1 & flag_treated==0 


* 3.) pe regressions
*************************

local varlist  peak_clicks
** agg_clicks_after agg_clicks_before

foreach var in `varlist' {
	* gen L0_peak_clicks_sq = L0_peak_clicks*L0_peak_clicks
	pe reg `var' L0_peak_clicks  , cluster(event_cluster_id)
	pe reg `var' L0_peak_clicks `crosslist' , cluster(event_cluster_id)
	** squared term
	pe reg `var' L0_peak_clicks  L0_peak_clicks_sq , cluster(event_cluster_id)

	
	pe reg `var' L0_peak_clicks  if L0_peak_clicks > 0, cluster(event_cluster_id)
	pe reg `var' L0_peak_clicks `crosslist' if L0_peak_clicks > 0, cluster(event_cluster_id)
	** squared
	pe reg `var' L0_peak_clicks  L0_peak_clicks_sq if L0_peak_clicks > 0, cluster(event_cluster_id)

	
	local if_condition "if placebo_state==0 & flag_treated"
	pe reg `var' L0_peak_clicks  `if_condition', cluster(event_cluster_id)
	pe reg `var' L0_peak_clicks `crosslist' `if_condition', cluster(event_cluster_id)
	** squared
	pe reg `var' L0_peak_clicks  L0_peak_clicks_sq `if_condition', cluster(event_cluster_id)

	local if_condition "if placebo_state==0 & flag_treated & L0_peak_clicks > 0"
	pe reg `var' L0_peak_clicks  `if_condition', cluster(event_cluster_id)
	pe reg `var' L0_peak_clicks `crosslist' `if_condition', cluster(event_cluster_id)
	** squared
	pe reg `var' L0_peak_clicks  L0_peak_clicks_sq `if_condition', cluster(event_cluster_id)

	local if_condition ""
		local extra_controls eligible_and_treated
	pe reg `var' L0_peak_clicks  `extra_controls' `if_condition', cluster(event_cluster_id)
	pe reg `var' L0_peak_clicks  `extra_controls' `crosslist' `if_condition', cluster(event_cluster_id)
	** squared
	pe reg `var' L0_peak_clicks  L0_peak_clicks_sq `extra_controls' `if_condition', cluster(event_cluster_id)


	}
	

* local texoutput_file "wikidis_explore-heterogeneities.tex"
* local table_slides_path "${PATH_PAPER_MAIN}wiki_slides"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"
cap mkdir `table_stand_alone_path'


local estlabel "HeterogPeaks"
local var  peak_clicks
** agg_clicks_after agg_clicks_before
/* estimates */	
	
* local if_condition "if placebo_state==0 & flag_treated & L0_peak_clicks > 0"
local if_condition "if placebo_state==0 & flag_treated "
pe reg `var' L0_peak_clicks  `if_condition', cluster(event_cluster_id)
estimates store `estlabel'1
estadd ysumm

** squared
pe reg `var' L0_peak_clicks  L0_peak_clicks_sq `if_condition', cluster(event_cluster_id)
estimates store `estlabel'2
estadd ysumm


pe reg `var' L0_peak_clicks L0_peak_clicks_sq `crosslist' `if_condition', cluster(event_cluster_id)
estimates store `estlabel'3
estadd ysumm



local if_condition ""
local extra_controls eligible_and_treated

pe reg `var' L0_peak_clicks  `extra_controls' `if_condition', cluster(event_cluster_id)
estimates store `estlabel'4
estadd ysumm

** squared
pe reg `var' L0_peak_clicks  L0_peak_clicks_sq `extra_controls' `if_condition', cluster(event_cluster_id)
estimates store `estlabel'5
estadd ysumm

pe reg `var' L0_peak_clicks  L0_peak_clicks_sq  `extra_controls' `crosslist' `if_condition', cluster(event_cluster_id)
estimates store `estlabel'6
estadd ysumm

	
	

	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		local time time_var 		/* add some dummy if it is a crosssection */
		local obs_id page_id		/* specify the adequate variable */
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

 
* extend as required

	local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5  `estlabel'6"
	local mgroupsoption " "just the treated" "controlling treated", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles A B C D E F
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of the Attention Peak in treated articles (L0) and their neighbors (L1)"
	local scaling "50" /* in percent (0-100) */
	local widthlocal "21.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
	local addnotetext1 "Pooled OLS-Regressions with robust standard errors."
	local addnotetext2 "Only x y z. Dependent Variable: `outcome`x''."
	local signs_to_erase_in_notes 166 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the results of the reduced form regressions to estimate the relationship between the peak in viewership of the treated article /*
				*/ and the peak on the neighbors. Columns (1)-(3) show only treated observations and /*
				*/ Columns (4)-(6) include all articles and control for treatment.  Specifications (1) and (4) give the raw correlations;  /*
				*/ (2) and (5) show a quadratic specification that allows for a concave relationship.  /*
				*/ In Columns (3) and (6) I contrast the relationship for different types of articles, /*
				*/ distinguishing them by their length and how well they are linked.  /* 
				*/ The unit of observations is the outcome of a page i on day 0, the day of treatment of the treated (L\_0) pages.  /*
				*/ Standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

	local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'.tex"
	local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/
			
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N N_g r2_a, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /* 
			in plugin_locals definieren
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
			in plugin_locals definieren
		*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
			in plugin_locals definieren
		*/ coeflabels(`L0_crossterm_labels' `position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
				in plugin_locals definieren
		*/ nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
			*/ _ "\_" "\end{tablular}" "\end{tablular*}")  /*

		topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
	
	/* call file that includes tablenotes */
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	


	
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
