/***********/ local filename = "template_standard_analysis" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close

cap cd wikidis_plugin/mkm_extras_copy/
local texoutput_file "heterog_slides.tex"
local table_slides_path "${PATH_PAPER_SLIDES}wikidis_auto_slides"
local table_stand_alone_path "temp_tables_n_graphs/"
local graph_path "${PATH_FIGURES}"

cap mkdir `table_stand_alone_path'


cap include "../wikidis_plugin_locals.do"
*include "${PATH_PLUGIN}wikidis_plugin_locals.do"
include "${PATH_EXTRA_PLUGIN}print_execute.do" /* not defined, but pe lies in same folder. */

log using "`table_stand_alone_path'/`filename'.log", replace
*log using "${PATH_LOGS}/`filename'.log", replace



**** Short description of do-file:
/* This do file takes the dataset you specify and 
	* makes descriptives
	* plots the variable of interest
	* runs regressions 
	* => Auto build of pdf => then that tex-file should also come in the plugin-folder...
desc_end ***/



* set up a tex-file for viewing all the outputs of this analysis
**********
local includer_name "`filename'_caller.tex"
local file_includer file_fig_caller
cap file close `includer_name' 
* cap file erase `includer_name' 
pe file open `file_includer'  using `includer_name', write replace



*** DEFINE ALL THE IMPORTANT VARIABLES HERE (maybe customize for the Regressions and Plots
***********
local DisPod PoD
local linkdistance L1
local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_with_link_position_in_L0.dta"
	/* choose carefully */
use "`startdata'", clear


** Define the most relevant Variables
**************************

local main_depvar peak_clicks
local other_depvars   peak_del_num_revisions peak_del_num_authors 
	/* more devars: does not need to be filled - would generate a table each */
local depvarlist `main_depvar' `other_depvars'

local var_extra_category link_20_aggregator /* can remain empty: or contain gender, category or flag_treated if sample is to be distinguished */
local sampling_crit "1==1" 
	/* either empty condition or sth with bite: e.g.:  "link_20_aggregator > 2 " */
local sampling_condition "if `sampling_crit'"
local counter_sampling_cond "if (`sampling_crit') == 0 "
 

local var_of_interest_A flag_link_20_1 flag_link_20_2 flag_link_20_3 flag_link_20_4 
** local var_of_interest_A `link_group_flags'
local var_of_interest_B link_position_relative   /* sq_link_position_relative */
local var_of_interest_C link_20_aggregator
local other_plot_x_vars num_repetitions_link

local vars_of_interest "`var_of_interest_A' `var_of_interest_B' `var_of_interest_C' `var_of_interest_D'"

local controls_i /* e.g. empty */
	* alternative: link_position_in_L0
local controls_j num_revisions num_authors page_length num_imagelinks SNwik_degree 
local controls_k `controls_j' flag_stub flag_long flag_linked flag_super_l1 
local controls_l `controls_k' num_repetitions_link num_L0_links num_links_from_l1 /* e.g. empty */

local reg_controls `controls_i' `controls_j' `controls_k' `controls_l'

local vars_for_sumstats `depvarlist' `var_extra_category' `vars_of_interest' `reg_controls'  
local vars_to_summarize `depvarlist' `var_extra_category' `vars_of_interest' `reg_controls'  
local vars_to_correlate `depvarlist' `var_extra_category' `vars_of_interest' 


** identify outliers
**************************
local outlier_vars `depvarlist' `vars_of_interest'
gen flag_outlier = 0
foreach var in `outlier_vars' {
	centile `var' `sampling_condition', centile(99 98 99.5)
	di int(r(c_3))
	replace flag_outlier = 1 if `var' > int(r(c_3))
	}

local no_outlier_extension "& flag_outlier == 0" /* & flag_outlier == 0 */ 

** IF conditions that reduce observation set for the entire estimation and data description
***********************************
local if_condition_1 "if `sampling_crit' " /* possibly a `sampling_condition' - "if 1==1" => full sample */ 
local if_condition_2 `if_condition_1'  `no_outlier_extension' /* by default: local if_condition_2 `if_condition_1' - change if otherwise desired */
** possible but not intended:  local if_condition_3 `if_condition_1'  /* by default: local if_condition_2 `if_condition_1' - change if otherwise desired */


*********************
* DESCRIPTIVE TABLES
*********************
local desc_tabs_path  `table_stand_alone_path' /* path for descriptive tables */
local vars_to_summarize `vars_for_sumstats'
	/* vars_for_sumstats is defined in template_standard_analysis 
		-- alternatively define before calling here (if you call (or worse: copy-pasted) just the sumstats part... */
		
	pe file write  `file_includer' _n "\section{DESCRIPTIVE TABLES}" _n 

	***
	dis "* All Observation in Sample"
	***

	sum `vars_to_summarize'
		local sumstatfilename "`desc_tabs_path'`filename'`TableNameLabel'.tex"

		local TableNameLabel "FullSample" /* don't change the name of local if you wnat the label in latex) !! */
		local titletext "Summary statistics: `TableNameLabel'  of main variables"
		local sumstats_table_file "`desc_tabs_path'`filename'_desc_`TableNameLabel'.tex"

		estpost summarize `vars_to_summarize' , detail   
		esttab  . using "`sumstats_table_file'" , /*
			*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p50(fmt(%11.2g))  p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
			*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
			*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
			*/ booktabs replace  /*
			*/ order(`stand_varorder')		

			
	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */

		* file write  `file_includer' "\begin{landscape}" _n
		pe file write  `file_includer' _n "\input{`sumstats_table_file'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		pe file write  `file_includer' _n
		
	
	dis "*** subsample " 

		local TableNameLabel "Subsample" /* don't change the name of local if you wnat the label in latex) !! */
		local titletext "Summary statistics: `TableNameLabel'  of main variables `sampling_condition'"
		local sumstats_table_file "`desc_tabs_path'`filename'_desc_`TableNameLabel'.tex"
		
		* version for and_overiew
		estpost summarize `vars_to_summarize' `sampling_condition', detail   
		esttab  . using "`sumstats_table_file'" , /*
			*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p50(fmt(%11.2g))  p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
			*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
			*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
			*/ booktabs replace  /*
			*/ order(`stand_varorder')
			
	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */

		* file write  `file_includer' "\begin{landscape}" _n
		pe file write  `file_includer' _n "\input{`sumstats_table_file'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		pe file write  `file_includer' _n

			
	dis "*** COUNTER SUBSAMPLE" 
			
		local TableNameLabel "CounterSample" /* don't change the name of local if you wnat the label in latex) !! */
		local titletext "Summary statistics: `TableNameLabel'  of main variables `counter_sampling_cond'"
		local sumstats_table_file "`desc_tabs_path'`filename'_desc_`TableNameLabel'.tex"
		
		* version for and_overiew
		estpost summarize `vars_to_summarize' `counter_sampling_cond', detail   
		esttab  . using "`sumstats_table_file'", /*
			*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
			*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
			*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
			*/ booktabs replace  /*
			*/ order(`stand_varorder') /*
			*/ coeflabels(`varname_labels') 

	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */

		* file write  `file_includer' "\begin{landscape}" _n
		file write  `file_includer' _n "\input{`sumstats_table_file'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		file write  `file_includer' _n
		
		/* version for slides
		local sumstats_table_file "${PATH_PAIRS_DESC_TABLES}`filename'`TableNameLabel'_CounterSample.tex"
		estpost summarize `vars_to_summarize' `if_condition', detail   
		esttab  . using "`sumstats_table_file'" , /*
			*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
			*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
			*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
			*/ booktabs replace  /*
			*/ order(`stand_varorder') */


** CORRELOGRAMS
********************
		
	sort page_id time_var
	
	* of the levels
	pwcorr `vars_to_correlate'
	* pwcorr `outcomes' `futher_SN_vars'

	preserve
	*** kill the labels for all variable 
	foreach var_to_label in time_var  `vars_to_correlate' /**/ {
		label var `var_to_label' ""
		}

	corrtex `vars_to_correlate' , file(`desc_tabs_path'`filename'_corrs_main) sig replace landscape title("Correlations of the levels")
	file write `file_includer' _n "\input{`desc_tabs_path'`filename'_corrs_main.tex}" _n _n

	corrtex `vars_to_correlate' `sampling_condition', file(`desc_tabs_path'`filename'_corrs_more) key(CorrsSubSamp) sig replace landscape title("Correlations of the levels for Subsample")
	file write `file_includer' _n "\input{`desc_tabs_path'`filename'_corrs_more.tex}" _n _n
	restore


/* taboulate the different events (observations: */


	local TableNameLabel "TabulateCategs"
	tab `var_extra_category'
	local tabulate_file "`desc_tabs_path'`filename'`TableNameLabel'.tex"
	pe tabout `var_extra_category'  using `tabulate_file', replace style(tex)
	
 
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n    "\begin{table}[h]"
	file write  `file_includer' _n " \caption{Observations per Category}"
	file write  `file_includer' _n    "\begin{center}"
    file write  `file_includer' _n "\begin{tabular}{l|c|r} \toprule  "
	file write  `file_includer' _n "\input{`tabulate_file'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
    file write  `file_includer' _n "\bottomrule \end{tabular}"
	file write  `file_includer' _n "\end{center}"
	file write  `file_includer' _n "\end{table}"
	file write  `file_includer' _n

	local TableNameLabel "TabulateCategsSamp"
	local tabulate_file "`desc_tabs_path'`filename'`TableNameLabel'.tex"
	tabout `var_extra_category' `sampling_condition' using `tabulate_file', replace style(tex)
	
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n    "\begin{table}[h]"
	file write  `file_includer' _n " \caption{Observations in Subsample per Category}"
	file write  `file_includer' _n    "\begin{center}"
    file write  `file_includer' _n "\begin{tabular}{l|c|r} \toprule  "
	file write  `file_includer' _n "\input{`tabulate_file'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
    file write  `file_includer' _n "\bottomrule \end{tabular}"
	file write  `file_includer' _n    "\end{center}"
	file write  `file_includer' _n "\end{table}"
	file write  `file_includer' _n
	
			
			
			
* DESCRIPTIVE FIGURES
**************
local storepath `graph_path'
local graphname linkposition_on_click_peaks

local variables_x /*`vars_of_interest_A'*/ `vars_of_interest_B' `vars_of_interest_C' `other_plot_x_vars' 
	/* => put several if you want real iteration */
	/* default: local variables_x `vars_of_interest_A' `vars_of_interest_B' `vars_of_interest_C'  `other_plot_x_vars' */
local variables_y `depvarlist' /* anything else typically should not make sense... */
	/* put several if you want real iteration */

local var_plot_categ  `var_extra_category' /* some seperator like gender or category: does not need to be filled */


foreach depvar in `depvarlist' {
	local labelcounter = `labelcounter'+1 

	local descriptive_plots_yes "yes" /* "yes" or "no" */
	if "`descriptive_plots_yes'" == "yes" {

	local var_to_plot `depvar'
		local counter_y = `counter_y'+1
		foreach var_x_axis in `variables_x' {
		/* choose order in which you want to iterate by excahnging y and x loop */
			local counter_x = `counter_x'+1
			local graph_file `storepath'`graphname'_`var_x_axis'
			local titletext "`var_to_plot' on `var_x_axis'"
			sum `var_x_axis'
			local xrange = r(max) - r(min)
			local xlim_low = r(min) - `xrange'*0.1 
			local xlim_hi = r(max) + `xrange'*0.1
			pe file write  `file_includer' _n "\subsection{Plots: iteration `counter_y' `counter_x'}" _n
			
			pe by `var_x_axis', sort: sum `var_to_plot'
			cap drop mean_`var_to_plot'
			pe by `var_x_axis' `var_plot_categ', sort: egen mean_`var_to_plot' = mean(`var_to_plot')
			
			pe hist `var_x_axis', freq addlabels title(Distribution of `var_x_axis')
			local temp_graph_filename `graph_file'_hist_cont.png
			pe graph export `temp_graph_filename' , replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			pe hist `var_x_axis', discrete freq addlabels title(Distribution of `var_x_axis')
			local temp_graph_filename `graph_file'_hist_categ.png
			pe graph export `temp_graph_filename' , replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 

			sort `var_x_axis' `var_plot_categ' start_page_name page_id

			

			** Means of depvar vs. x-axis
			* Clean+Neat alternative
			preserve 
				pe collapse `var_to_plot', by (`var_x_axis' `var_plot_categ')
				pe scatter `var_to_plot' `var_x_axis', title(`titletext') connect(direct) mcolor(cranberry) msize(large) /* jitter(20) */
				local temp_graph_filename  `graph_file'_mean_`var_to_plot'.png
				pe graph export `temp_graph_filename', replace
				file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			restore

			* jitter
			pe scatter mean_`var_to_plot' `var_x_axis', xsc(range(`xlim_low' `xlim_hi')) ysc(fextend) title(`titletext' with freq.) /*connect(direct)*/ mcolor(cranberry) msize(vtiny)  jitter(8) 
			local temp_graph_filename `graph_file'_mean_`var_to_plot'_jitter.png
			graph export `temp_graph_filename', replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			
			
			* messy: all dots (no means) of it wit lfit
			pe scatter `var_to_plot' `var_x_axis', title(`titletext' with line-plot) xsc(extend) ysc(extend) /* connect(direct)*/ mcolor(cranberry) msize(vtiny) /*
				*/ || lfit `var_to_plot' `var_x_axis', lwidth(thick)
			local temp_graph_filename `graph_file'_`var_to_plot'.png
			pe graph export `temp_graph_filename', replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			
			
			pe file write  `file_includer' _n "\clearpage" _n
		}
		local counter_x 
	} 




	* A simple regression for TRY ERROR
	**************************

	pe file write  `file_includer' _n "\section{TRY and ERROR regressions}" _n

	local estlabel "TryErrorRegs"
	
	local reg_command regress
	
	local reg_options_1 "" /**/
	local reg_options_2 `reg_options_1' /* by default: local options_2 `options_1' - change if otherwise desired */
	** local reg_options_3 `options_1' /* by default: local options_2 `options_1' - change if otherwise desired */

	local variables_interest A B
		/* A B C D */
	local controls_interest i j k l
		/* i j k l */
		/* careful!, only 1 loop expected at the bottom, 
			=> make sure to deactivate the i_j_k loop if you wnat to iterate over vars of interest...
			=> for additional table per var of interest add options B C etc..... */
	foreach A_B_C in `variables_interest' { 
        local auto_reg_list = "" /* container leeren */
		local auto_column_titles ""
		pe local auto_groups ""
		foreach variant_of_reg in 1 2  { 
			/* default local variant_of_reg 1 2 */ 
			local counter_rd = 1
			foreach i_j_k in `controls_interest'{
			
				** specify controls, options and label.
				local var_x_in_reg `var_of_interest_`A_B_C'' `controls_`i_j_k''/* by default: local var_x_in_reg_A `var_of_interest_A' - change if otherwise desired */
				local version `variant_of_reg'
				local if_condition `if_condition_`version''
				local options `reg_options_`version''
					

				/* estimates */
				pe `reg_command' `depvar' `var_x_in_reg' `if_condition' `options'
				pe estimates store `estlabel'`i_j_k'`variant_of_reg'
				estadd ysumm
				
				local auto_reg_list = "`auto_reg_list' `estlabel'`i_j_k'`variant_of_reg'"
				pe di "auto_reg_list = `auto_reg_list'"
				local auto_column_titles  "`auto_column_titles'  "spec. `i_j_k'`variant_of_reg'" "
				if `counter_rd' == 1 {
					local auto_groups `auto_groups' 1
					}
				if `counter_rd' != 1 {
					local auto_groups `auto_groups' 0
					}
				local counter_rd = `counter_rd' + 1
				}

			}

		**** objects in table:
		/* check out how many events, pages, observatoins and days are in the dataset  
			and provide that info as local */
			local time  flag_treated		/* add some dummy if it is a crosssection */
			local obs_id page_id		/* specify the adequate variable */
			local cluster_id start_page_name
			
			include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `auto_reg_list'"
			local mgroupsoption " "Group 1" "Group 2", pattern(`auto_groups') prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
			local columntitles " `auto_column_titles' "
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "TRY AND ERROR REG: Dependent variable: `depvar', Var of Interest: `var_of_interest_`A_B_C''"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "22.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition "NOCH SPEZIELLERE BEMERKUNG "
				}
			pe local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table shows a regression of SPEZIELLE BEMERKUNGEN /*
					*/ `notetext_addition'/*
					*/ ; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'_`depvar'_`A_B_C'.tex"
			local latexlabel `estlabel'`labelcounter'`A_B_C' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

			pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N N_g r2_a ymean, fmt(0 0 2) labels("Observations" "Number of Groups" "Adj. R$^2$" "Mean of dep. var.")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(3) t(2) nogaps /*  nodepvars compress (nodepvars: no modeltitles, nogaps: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption') /*
				*/ mtitles(`columntitles') /*
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
			
			/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
				file write  `file_includer' "\begin{landscape}" 
				file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
				file write  `file_includer' "\end{landscape}" _n
				file write  `file_includer' _n
			
	}	
	pe file write  `file_includer' _n "\clearpage" _n
	est clear
}
local counter_y 


pe file close `file_includer' 

local build_pdf_yes = "yes" 
if "`build_pdf_yes'" == "yes" {
	
/* build tables and graphs viewer */
	* cd "${PATH_PAPER_TEXT}"
	!pdflatex template_standard_analysis_tables_and_graphs_viewer.tex -no-shell-escape
	* cd "${PATH_TO_DO}"
	
}

! template_standard_analysis_tables_and_graphs_viewer.pdf 

local helpfile_endings aux log out tex.bak
foreach endg in `helpfile_endings' {
	cap erase template_standard_analysis_tables_and_graphs_viewer.`endg'
	}

clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

cap log close
exit
*************************************************************************************
*************************************************************************************



	* A simple regression for TRY ERROR
	**************************

	pe file write  `file_includer' _n "\section{TRY and ERROR regressions}" _n

	local estlabel "TryErrorRegs"

	local variables_interest A B C
	local var_x_in_reg_A `var_of_interest_A' /* by default: local var_x_in_reg_A `var_of_interest_A' - change if otherwise desired */
	* gen sq_link_position_relative = link_position_relative*link_position_relative
	local var_x_in_reg_B `var_of_interest_B' /* by default: local var_x_in_reg_A `var_of_interest_A' - change if otherwise desired */
	local var_x_in_reg_C `var_of_interest_C' /* by default: local var_x_in_reg_A `var_of_interest_A' - change if otherwise desired */

	local variant_of_reg 1 /* default local variant_of_reg 1 2 */
		local if_condition_1 "if link_20_aggregator > 2" 
		local if_condition_2 `if_condition_1'  /* by default: local if_condition_2 `if_condition_1' - change if otherwise desired */
		** possible but not intended:  local if_condition_3 `if_condition_1'  /* by default: local if_condition_2 `if_condition_1' - change if otherwise desired */

		local options_1 ", robust" /**/
		local options_2 `options_1' /* by default: local options_2 `options_1' - change if otherwise desired */
		** local options_3 `options_1' /* by default: local options_2 `options_1' - change if otherwise desired */

	foreach A_B_C in `variables_interest' {
		local var_of_interest `var_x_in_reg_`A_B_C''
		* foreach version in `variant_of_reg'
			local version = 1
			local if_condition `if_condition_`version''
			local options `options_`version''
			

		/* estimates */
		pe regress `depvar' `var_of_interest' `if_condition' `options'
		estimates store `estlabel'1
		estadd ysumm

		pe regress `depvar'  `var_of_interest' `page_chars' `if_condition' `options'
		estimates store `estlabel'2
		estadd ysumm


		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars'  `if_condition' `options'
		estimates store `estlabel'3
		estadd ysumm


		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' `network_vars' `if_condition' `options'
		estimates store `estlabel'4
		estadd ysumm  

		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' `other_criteria' `network_vars' `if_condition' `options'
		estimates store `estlabel'5
		estadd ysumm  





			**** objects in table:
			/* check out how many events, pages, observatoins and days are in the dataset  
				and provide that info as local */
				local time  flag_treated		/* add some dummy if it is a crosssection */
				local obs_id page_id		/* specify the adequate variable */
				local cluster_id start_page_name
				
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5"
			local mgroupsoption 
			/* " "Group 1" "Group 2", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" */
			local columntitles A B C D E
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "TRY AND ERROR REG: No Quintile 1 Dependent variable: `depvar'"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "16.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition The robustness regression is without the first quintile, which represents the neighbors that are /*
						*/ mentioned among the first 20\% of links in the outgoing page. The third quintile are article /*
						*/ in the middle and the last quintile was linked at the end of the outgoing page. 
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table shows the download frequency for articles grouped by their order of /*
					*/ appearance in the treated article. `notetext_addition' In Column 2 /*
					*/ I control for the article characteristics (length and network-characteristcs), and in Column 3 I control /*
					*/ for the total number of links on the outgoing (L\_0) pages and the abolute number of links /*
					*/ from other neighbors (in L\_1). Column 4 accounts for how often a given link was repeated /*
					*/ on the outgoing site. Column 5 finally introduces more variables that account for articles' /*
					*/ characteristics (length, past amount of contributions, etc.)/*
					*/ The Reference group are links in the 40-60 \% quintile; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'_`depvar'_`A_B_C'.tex"
			local latexlabel `estlabel'`labelcounter'`A_B_C' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

					pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N N_g r2_a ymean, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption') /*
				*/ mtitles(`columntitles') /*
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
			
			/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
				* file write  `file_includer' "\begin{landscape}" _n
				file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
				* file write  `file_includer' "\end{landscape}" _n
				file write  `file_includer' _n
			
	}	






** Reg for Paper
**************************

local estlabel "PositionRegs"

local variables_interest A B C
local var_x_in_reg_A `link_group_flags'
local var_x_in_reg_B link_position_relative  /* sq_link_position_relative */
local var_x_in_reg_C link_20_aggregator 

local depvarlist peak_clicks peak_del_num_revisions peak_del_num_authors peak_del_page_length
foreach depvar in `depvarlist' {
	local labelcounter = `labelcounter'+1 
	foreach A_B_C in `variables_interest' {
		local var_of_interest `var_x_in_reg_`A_B_C''
		

		/* estimates */
		pe regress `depvar' `var_of_interest'
		estimates store `estlabel'1
		estadd ysumm

		pe regress `depvar'  `var_of_interest' `page_chars'
		estimates store `estlabel'2
		estadd ysumm


		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' 
		estimates store `estlabel'3
		estadd ysumm


		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' `network_vars'  
		estimates store `estlabel'4
		estadd ysumm  

		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' `other_criteria' `network_vars' 
		estimates store `estlabel'5
		estadd ysumm  





			**** objects in table:
			/* check out how many events, pages, observatoins and days are in the dataset  
				and provide that info as local */
				local time  flag_treated		/* add some dummy if it is a crosssection */
				local obs_id page_id		/* specify the adequate variable */
				local cluster_id start_page_name
				
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5"
			local mgroupsoption 
			/* " "Group 1" "Group 2", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" */
			local columntitles A B C D E
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "Relationship of link position and additional attention. Dependent variable: `depvar'"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "16.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition The first quintile represents the neighbors that are /*
						*/ mentioned among the first 20\% of links in the outgoing page. The third quintile are article /*
						*/ in the middle and the last quintile was linked at the end of the outgoing page. 
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table shows the download frequency for articles grouped by their order of /*
					*/ appearance in the treated article. `notetext_addition' In Column 2 /*
					*/ I control for the article characteristics (length and network-characteristcs), and in Column 3 I control /*
					*/ for the total number of links on the outgoing (L\_0) pages and the abolute number of links /*
					*/ from other neighbors (in L\_1). Column 4 accounts for how often a given link was repeated /*
					*/ on the outgoing site. Column 5 finally introduces more variables that account for articles' /*
					*/ characteristics (length, past amount of contributions, etc.)/*
					*/ The Reference group are links in the 40-60 \% quintile; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'_`depvar'_`A_B_C'.tex"
			local latexlabel `estlabel'`labelcounter'`A_B_C' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

					pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N N_g r2_a ymean, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption') /*
				*/ mtitles(`columntitles') /*
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
			
			/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
				* file write  `file_includer' "\begin{landscape}" _n
				file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
				* file write  `file_includer' "\end{landscape}" _n
				file write  `file_includer' _n
			
	}	
	pe file write  `file_includer' _n "\clearpage" _n
	est clear
}

