**************************************
*** PREPARATION
**************************************


local path_to_folder = "${PATH_TO_SVN}"
* "O:/!_Projekte/SOZNET/A1_Wikipedia_Iassen/paper_msa_mkm_iha_ggi/Besprechungen_ibe_msa_mkm/Vorbereitung_120216"
local path_output = "${PATH_TABS_N_FIGS}"
local path_paper = "${PATH_PAPER_VIEWASPDF}"
local log_path = "${PATH_LOGS}"
cap mkdir `path_output'
cap mkdir `log_path'


include "${PATH_PLUGIN}wiki_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace


/*** Short description:
This do-file generates descriptives and graphs for SNA-measures and outcomes. 
	***/


* local data_path = ""
local figure_path = "${PATH_PANEL_FIGS}" 
local tex_path =  "${PATH_PANEL_TABLES}"
local figformat "eps"

cap mkdir `figure_path'
cap mkdir `tex_path'

use "${des_data_file}", clear


* N.B.: data contains outliers
*** alternative would be wiki_panel_p05p95

**** keep only D-articles
keep if is_article
*** define all the variables as locals in order to later centrally change single varanames

	** outcomes

	local clicks="clicks"
	local pg_length="page_length"
	local authors="num_authors"

	local outcomes = "`clicks' `pg_length' `authors' "  /*`core_outcomes'   ??*/
	local outcomes_main = "`pg_length'"

	** SNA-Variables

	local in_Degree = "SNwik_degree" 
	local out_Degree = "SNwik_out_degree"
	local closenes_global = "SNwik_closeness"
	local eigenvector_global = "SNwik_eigenvector"


	local in_Degree_local = "SNcat_degree"
	local closenes_local = "SNcat_closeness"
	local betweens_local = "SNcat_between"


	if "${des_data_file}" == "${PATH_PAPER_1_DATA}${WORKHORSE_DATASET}" {
		local SNA_variables = "`in_Degree_local' `in_Degree'  `closenes_local'  `closenes_global' "
		local SNA_main = " `closenes_local' `betweens_local' `closenes_global' `'  SNwik_rank_closeness"
	}


/* generate min and max vars here with foreach loop and egen by time_var*/

sort time_var page_id

** set up local container which is to be filled with the variables that are generated 
	local min_outcomes "" /* actually redundant => cf. how it is implemented for p10, which is however intranparent */
	local max_outcomes "" /* actually redundant => cf. how it is implemented for p10 */


	foreach vari in `SNA_variables'   {
		by time_var: egen mean_`vari' = mean(`vari')
		local mean_outcomes `mean_outcomes' mean_`vari'
		by time_var: egen min_`vari' = min(`vari')
		local min_SNA_vars `min_SNA_vars' min_`vari'
		by time_var: egen max_`vari' = max(`vari')
		local max_SNA_vars `max_SNA_vars' max_`vari'
		by time_var: egen p90_`vari' = pctile(`vari'), p(90)
		local p90_SNA_vars `p90_SNA_vars' p90_`vari'
		by time_var: egen p10_`vari' = pctile(`vari'), p(10)
		local p10_SNA_vars `p10_SNA_vars' p10_`vari'
		di "variable is `vari'"
		}

		

	foreach vari in `outcomes' `further_SN_vars' {
		by time_var: egen mean_`vari' = mean(`vari')
		local mean_outcomes `mean_outcomes' mean_`vari'
		by time_var: egen min_`vari' = min(`vari')
		local min_outcomes `min_outcomes' min_`vari'
		by time_var: egen max_`vari' = max(`vari')
		local max_outcomes `max_outcomes' max_`vari'
		by time_var: egen p90_`vari' = pctile(`vari'), p(90)
		local p90_outcomes `p90_outcomes' p90_`vari'
		by time_var: egen p10_`vari' = pctile(`vari'), p(10)
		local p10_outcomes `p10_outcomes' p10_`vari'
		di "variable is `vari'"
		}


	*** shorten the labels for all variable 
	foreach var_to_label in time_var   `core_outcomes' `core_SN_vars'  {
		local cutlabel  : variable label `var_to_label'
		local shortlabel = substr("`cutlabel'",1 ,31)
		label var `var_to_label' "`shortlabel'"
		des `var_to_label'
		}
		
	sort page_id time_var

**************************************
*** ANALYSIS
**************************************


*** sum, details of levels
********************************

sum `clicks', detail
sum `pg_length', detail
sum `authors', detail

foreach SNA_var in  `SNA_variables' `further_SN_vars' {
	sum `SNA_var', detail
	}
	
** sum, details of first differences
********************************************	

sum d.`clicks', detail
sum d.`pg_length', detail
sum d.`authors', detail
foreach SNA_var in `SNA_variables' {
	sum d.`SNA_var', detail
	}



*******************************************
*** correlations
********************************************
	
	local tex_path ${PATH_DESCRIPTIVES_TABLES}
	
	sort page_id time_var
	local vars_to_correlate `core_outcomes' `core_indep_vars' `core_SN_vars' `del_vars'
	
	* of the levels
	pwcorr `vars_to_correlate'
	* pwcorr `outcomes' `futher_SN_vars'

	*** kill the labels for all variable 
	foreach var_to_label in time_var  `vars_to_correlate' /**/ {
		label var `var_to_label' ""
		}

		
		
	corrtex `core_indep_vars' `core_outcomes' , file(`tex_path'corrs_levels) sig replace landscape title("Correlations of the levels")
	file write `file_includer' _n "\input{`tex_path'corrs_levels.tex}" _n _n

	corrtex `core_indep_vars' `del_vars' `core_SN_vars' , file(`tex_path'corrs_further_levels) sig replace landscape title("Correlations of the levels")
	file write `file_includer' _n "\input{`tex_path'corrs_further_levels.tex}" _n _n
	
	

********************************************		
*** corr page_length closeness
********************************************

	local k 4
	local vari `closenes_local'


	foreach vari in `SNA_main' {
		gen lag_`vari' = L.`vari'
		gen lag`k'_`vari' = L`k'.`vari'
		pwcorr `pg_length' `vari' lag_`vari' lag`k'_`vari'
		corrtex `pg_length' `vari' lag_`vari' lag`k'_`vari', file(`tex_path'/corrs_`vari') sig replace noscreen 
		file write table_includer "\input{`tex_path'corrs_`vari'.tex}" _n
		}

	file close table_includer 


	if "${des_data_file}" != "${PATH_PAPER_1_DATA}/wiki_panel_connected_eco.dta" {

	/* generate crosstab with rel_closeness_rank_bins. More general version cf. wiki_2_gen_bins.do 
	=> geht nicht im MSA Datensatz */

	drop mean_*
	drop min_*
	drop max_*
	local more_ranks_n_closeness_bins_yes "yes"
	include wiki_plugin/wiki_plugin_addvars

	local begin = 1
	local mid = 76
	local last = 152

	sort page_id time_var
	by page_id: gen SNwik_rank_closeness_bin`begin' = SNwik_rank_closeness_bin_t[`begin']
	label var SNwik_rank_closeness_bin`begin' "centrality`begin'"
	by page_id: gen SNwik_rank_closeness_bin`mid' = SNwik_rank_closeness_bin_t[`mid']
	label var SNwik_rank_closeness_bin`mid' "centrality`mid'"
	by page_id: gen SNwik_rank_closeness_bin`last' = SNwik_rank_closeness_bin_t[`last']
	label var SNwik_rank_closeness_bin`last' "centrality`last'"



	tab SNwik_rank_closeness_bin`begin' SNwik_rank_closeness_bin`last'
	tab SNwik_rank_closeness_bin`begin' SNwik_rank_closeness_bin`mid'
	tab SNwik_rank_closeness_bin`mid' SNwik_rank_closeness_bin`last'

**********************************************
* export crosstabss to tex using tabout
**********************************************

local outputpath = "${PATH_DESCRIPTIVES_TABLES}" 
local outputfilename = "sumtabs_rank_rel"
local path_manual_stata_tex = "${PATH_STATA_LOCAL}"



local tabout_name = "_closeness_transition"
tabout  SNwik_rank_closeness_bin`begin' SNwik_rank_closeness_bin`last' /*
*/ using `outputpath'`outputfilename'`tabout_name'.tex, /* 
*/ cells(freq col) format(0 2) clab(No. Col_%) replace  style(tex) /*
*/ topf(`path_manual_stata_tex'/top_example.tex) botf(`path_manual_stata_tex'/bot_example.tex) /*
*/ topstr(14cm) botstr(wikipedia\_data.dta)

}

log close





