/* locals for data management */
************************************

local DisPod = "${DisPod}"
local link_distances_numbers = "${linksets}"

local features = "${FEATURES}"


foreach distance in `link_distances_numbers' {
	local link_distance_sets `link_distance_sets' L`distance'
	}

local linklabeltext_L0 = "directly shocked articles"
local linklabeltext_L1 = "direct neighbors of shocked articles"
local linklabeltext_L2 = "indirect neighbors of shocked articles (2 clicks away from epicenter)"

local datatext_dis = "large events condition"
local datatext_PoD = " 'featured articles' condition"

foreach Lx in `link_distance_sets' {
	di "displaying `linklabeltext_`Lx'' in the  `datatext_`DisPod'' "
	}


local browse "*browse"	
local viewtime 2000
	
/* locals for grouping variables centrally */
****************************************


local panel_key flag_treated start_page_name page_id placebo_state 
	/* man key for sorting (e.g. for "bysort BLA: egen"): identifies a 29d-time series  */
local unique_key `panel_key' time_var


local core_SN_vars = "SNwik_degree "
	* SNcat_degree SNcat_closeness SNcat_out_closeness SNcat_between SNwikcat_degree  SNwik_closeness
local core_outcomes  clicks page_length num_imagelinks has_lit num_refs num_extlinks num_authors num_revisions
local core_indep_vars time_var page_langlinks
local log_vars  log_SNcat_closeness log_SNcat_degree log_SNwik_degree log_clicks log_page_length log_num_authors /* log_SNcat_between */
local del_vars "del_num_revisions del_page_length del_num_authors del_SNwik_degree del_num_imagelinks del_num_refs del_num_extlinks "
local outcomes_long_term "page_length num_authors num_refs num_imagelinks num_extlinks SNwik_degree"

/* locals for table layout (esttab) */
*******************************
local varname_labels flag_treated "treated observation" placebo_state "placebo condition" has_lit "Dummy: literature section" num_authors "Number of authors" page_length /*
			*/ "Length of page (in bytes)" num_imagelinks "Number of images" num_refs "References (footnotes)"/*
			*/  num_extlinks "External Links (web)" page_langlinks "Number language links" /*
			*/ age "Age (in months)" _cons "Constant" clicks "Clicks" num_revisions "Number of Revisions" /*
			*/ SNwik_degree "Links from Wikipedia" time_var "time variable (normalized)" /*
			*/ del_num_authors "Delta: Number of authors" del_page_length  "Delta: Length of page" /*
			*/ del_num_imagelinks "Delta: Number of images" del_num_refs "Delta: References"/*
			*/  del_num_extlinks "Delta: External Links (web)" del_page_langlinks "Delta: language links" /*
			*/  del_clicks "Delta: Clicks" del_num_revisions "Delta: Number of Revisions" del_SNwik_degree "Delta: Links from Wikipedia"
			
			/* SNcat_closeness "Article's closeness in category" SNwik_closeness "Article's closeness on Wikipedia" /*
			*/SNwik_rank_closeness "Rel. closeness rank (Wikipedia)" SNcat_rank_closeness "Rel. closeness rank (category)" /*
			 SNcat_degree "Links from category" SNwikcat_degree  "Links from Wikipedia excl. categ." /*
			*/SNwik_degree2 "(Links from Wikipedia)$^2$" SNcat_degree2 "(Links from category)$^2$" SNwikcat_degree2  "(Links from Wikipedia excl categ.)$^2$"/* 
			*/ time_var "time trend" is_redirect "Dummy: page is redirect" is_con_locclosin "Dummy: page is connected to cat." /*
			*/ age "Age (in months)" _cons "Constant" clicks "Clicks" num_revisions "Number of Revisions"
			*/ */

local heterogeneity_labels flag_super_l1 "many L1 links article " flag_linked "well linked article " /*
	*/ flag_long "long article "  flag_stub "short article  " num_links_from_l1  "links oth. neighbors (L1)"

local position_var_labels link_position_relative "link's position in L0 article" max_link_position_rel /*
	*/ "last position of link in article"  num_repetitions_link "frequency of link's appearance in L0" /*
	*/ 	link_position_in_L0 "position of link in L0 article (abs.)" num_L0_links "\textbf{Number of links in L0}" /*
	*/  wordcount1 "Length of L0 article" L0_peak_clicks "\textbf{Clicks on L0 article}" /*
	*/  L0_peak_clicks_sq "(Clicks on L0 article)$^2$"  L0_clicks_per_link "\textbf{Clicks per link on L0}"
	
	
local  position_bin_labels  flag_link_20_1 "Dummy: Link among first 20\% in L0" flag_link_20_2 "Dummy: Link among second 20\% in L0" /*
	*/ flag_link_20_3 "Dummy: Link among third  20\% in L0" flag_link_20_4 "Dummy: Link among fourth 20\% in L0" /*
	*/ flag_link_20_5 "Dummy: Link among fifth 20\% in L0" link_20_aggregator "\textbf{Quintile of link's appearance (in L0)}"

	
local iv_labels iv_TreatClicksL0_x_LinkQuint5 "Clicks $L0$ (Low Link)"	/*
	*/ 	iv_TreatClicksL0_x_LinkQuint4 "Clicks $L0$ (Mid-Low Link)"	/*
	*/	iv_TreatClicksL0_x_LinkQuint3 "Clicks $L0$ (Middle Link)"	/*
	*/	iv_TreatClicksL0_x_LinkQuint2 "Clicks $L0$ (Mid-High Link)"	/*
	*/ 	iv_TreatClicksL0_x_LinkQuint1 "Clicks $L0$ (Early Link)"	
	
local position_labels `position_var_labels' `position_bin_labels'

local time_dummy_labels time_period15 "\textbf{t = 0}" time_period16 "t = 1" time_period17 "t = 2" time_period18 "t = 3" time_period19 "t = 4" /*
			*/ time_period14 "t = -1" time_period13 "t = -2" time_period12 "t = -3" time_period11 "t = -4" 


local cross_term_core_labels realtreat_x_period_15 "\textbf{t = 0}" realtreat_x_period_16 "t = 1" realtreat_x_period_17 "t = 2" 
			
			
local cross_term_labels `cross_term_core_labels' realtreat_x_period_18 "t = 3" realtreat_x_period_19 "t = 4" /*
			*/ realtreat_x_period_14 "t = -1" realtreat_x_period_13 "t = -2" realtreat_x_period_12 "t = -3" realtreat_x_period_11 "t = -4" 

local cross_dummy_labels  realtreat_x_neg_week2  "Before: days -14 to -8" /*
	*/ realtreat_x_days_neg7_to_neg4	"Before: days - 7 to -4" realtreat_x_days_neg3_to_neg1 "Before: days - 3 to -1" /*
	*/ realtreat_x_days_3_to_6 "After: days 3 to  6" realtreat_x_days_7_to_14 "After: days 7 to 14 "

			
local L0_crossterm_labels eligible_and_treated "eligible and treated observation" flag_stub_x_L0_peak_clicks "Clicks on L0 X long article" /*
	*/ flag_long_x_L0_peak_clicks "Clicks on L0 X long article " flag_linked_x_L0_peak_clicks "Clicks on L0 X well linked article " /*
	*/ flag_super_l1_x_L0_peak_clicks "Clicks on L0 X many L1 links article " 


local additional_features_labels flag_stub_x_day_14 "short article on t = -1" flag_stub_x_day_15 "short article on t = 0"  /*
	*/ flag_stub_x_day_16  "short article on t = 1"  flag_stub_x_day_17  "short article on t = 2"/*
	*/ flag_stub_x_day_22 "short article on t = 8"  flag_stub_x_day_27 "short article on t = 13" /*
	*/ flag_long_x_day_15 "long article on t = 0" flag_linked_x_day_15 "well linked article on t = 0" flag_super_l1_x_day_15 " many L1 links article on t = 0" /*
	*/ flag_long_x_day_16 "long article on t = 1" flag_linked_x_day_16 "well linked article on t = 1" flag_super_l1_x_day_16 " many L1 links article on t = 1"  /*
	*/ flag_long_x_day_17 "long article on t = 2" flag_linked_x_day_17 "well linked article on t = 2" flag_super_l1_x_day_17 " many L1 links article on t = 2"  					

*** What to include in regressions and what not ***

			
*time_period2 time_period3 time_period4 time_period5 time_period6 time_period7 
local periods_to_drop /*
		*/ time_period9 time_period10  time_period11 time_period12 time_period13 time_period14/*
		*/ time_period22 time_period21 time_period20 time_period19 time_period18 time_period17 time_period16 time_period15
		
local before_after_drop /*
		*/ time_period9 time_period10  time_period11 /*
		*/ time_period22 time_period21 time_period20 
		
		
* time_period29 time_period28 time_period27 time_period26 time_period25 time_period24 time_period23 
local crossterms_to_drop realtreat_x_period_11 realtreat_x_period_12 /*
		*/  realtreat_x_period_20 realtreat_x_period_21 realtreat_x_period_22
	
local crossterms_drop_bef_after /*
		*/  realtreat_x_period_20 realtreat_x_period_21 realtreat_x_period_22
		
local time_dummies = "time_period9-time_period22"
local day_dummies = "day_dummy2-day_dummy`num_days_in_sample'"

local reg_crossterms ""
forvalues cr = 11/22{
	local reg_crossterms  `reg_crossterms' realtreat_x_period_`cr'
	}

local reg_crossterm_dummies  realtreat_x_days_neg7_to_neg4	realtreat_x_days_neg3_to_neg1 /*
		*/ realtreat_x_period_15 realtreat_x_period_16 realtreat_x_period_17 /* Note: the time-variable for dummies runs from 1-29. 15 is period 0
		*/ realtreat_x_days_3_to_6 realtreat_x_days_7_to_14
		

****
*Variable Order
****
	
			
local first_varorder `core_SN_vars' `further_SN_vars' `core_outcomes'
local stand_varorder page_length num_authors clicks num_revisions /*
	*/ SNwik_degree /*
	*/ has_lit num_imagelinks page_langlinks num_refs num_extlinks 
	
	/* 
	SNwikcat_degree SNcat_degree /*
	*/ SNwik_rank_closeness SNcat_rank_closeness 
	*/	
	
local starsoption "starlevels( * 0.10 ** 0.05 *** 0.01)"
local postcomma_options " b(3) t(2) se(3)"
local standard_stats "stats(N N_g r2_a, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$"))"
local ymean_stats "stats(ymean N N_g r2_a, fmt(3 0 0 3) labels("Mean dep. Variable" "Observations" "Number of Pages" "Adj. R$^2$"))"


local stats_display_option `standard_stats' `starsoption' `postcomma_options' 
local ymean_stats_display_option `ymean_stats' `starsoption' `postcomma_options' 


*** for descriptives:
local stformat "fmt(%09.2g)"


/* locals for file generation */
*********************************

if c(os) == "Unix" {
	local linux_plus +
	local linuxconst = 5 
	}
if c(os) == "Windows" {
	local linux_plus +
	local linuxconst = 0 
	}
local zew_stylefiles beamerthemezew.sty beamerouterthemezew.sty beamerinnerthemezew.sty beamerfontthemezew.sty beamercolorthemezew.sty /*
	*/ zewbeamer.cls zew_hgo.eps zew_hgu.eps zew_hgo.pdf zew_hgu.pdf 
	

exit

*** ADAPT FROM WIKIPEDIA-PROJECT!! 
